@@ -1,14 +1,12 @@
+#ifndef ETTERCAP_VERS_H
+#define ETTERCAP_VERS_H
 
-
-#ifndef EC_VERS_H
-#define EC_VERS_H
-
-#define EC_VERSION            "0.8.0"
+#define EC_VERSION            "0.8.1"
 #define EC_VERSION_MAJOR      0
 #define EC_VERSION_MINOR      8
-#define EC_VERSION_REVISION   0
+#define EC_VERSION_REVISION   1
 #define EC_PROGRAM            "ettercap"
-#define EC_COPYRIGHT          "2001-2013"
+#define EC_COPYRIGHT          "2001-2014"
 #define EC_AUTHORS            "Ettercap Development Team"
 
 #endif
