@@ -323,6 +323,9 @@ FUNC_DECODER(dissector_gg)
 
    /* don't complain about unused var */
    (void)end;
+   (void) DECODE_DATA; 
+   (void) DECODE_DATALEN;
+   (void) DECODED_LEN;
    
    /* skip empty packets (ACK packets) */
    if (PACKET->DATA.len == 0)
