@@ -1,5 +1,5 @@
 /*
-    ettercap -- dissector RADIUS -- UDP 1645 1646
+    ettercap -- dissector RADIUS -- TCP/UDP 1645 1646 1812 1813
 
     Copyright (C) ALoR & NaGA
 
@@ -95,6 +95,10 @@ void __init radius_init(void)
 {
    dissect_add("radius", APP_LAYER_UDP, 1645, dissector_radius);
    dissect_add("radius", APP_LAYER_UDP, 1646, dissector_radius);
+   dissect_add("radius", APP_LAYER_TCP, 1812, dissector_radius);
+   dissect_add("radius", APP_LAYER_UDP, 1812, dissector_radius);
+   dissect_add("radius", APP_LAYER_TCP, 1813, dissector_radius);
+   dissect_add("radius", APP_LAYER_UDP, 1813, dissector_radius);
 }
 
 FUNC_DECODER(dissector_radius)
@@ -110,6 +114,11 @@ FUNC_DECODER(dissector_radius)
    char auth[0xff];
    size_t i;
    
+   /* don't complain about unused var */
+   (void) DECODE_DATA; 
+   (void) DECODE_DATALEN;
+   (void) DECODED_LEN;
+   
    DEBUG_MSG("RADIUS --> UDP dissector_radius");
 
    /* parse the packet as a radius header */
