@@ -26,8 +26,6 @@
 #include <ec_streambuf.h>
 #include <ec_checksum.h>
 
-#ifdef HAVE_OPENSSL
-
 
 /* don't include kreberos. RH sux !! */
 #define OPENSSL_NO_KRB5 1
@@ -141,6 +139,11 @@ FUNC_DECODER(dissector_ssh)
    u_int32 ssh_len, ssh_mod;
    u_char ssh_packet_type, *ptr, *key_to_put;
 
+   /* don't complain about unused var */
+   (void) DECODE_DATA; 
+   (void) DECODE_DATALEN;
+   (void) DECODED_LEN;
+   
    /* skip empty packets (ACK packets) */
    if (PACKET->DATA.len == 0)
       return NULL;
@@ -153,7 +156,7 @@ FUNC_DECODER(dissector_ssh)
     */
    
    if ((!GBL_CONF->aggressive_dissectors || GBL_OPTIONS->unoffensive || GBL_OPTIONS->read) 
-         || session_get(&s, ident, DISSECT_IDENT_LEN) == -ENOTFOUND) { 
+         || session_get(&s, ident, DISSECT_IDENT_LEN) == -E_NOTFOUND) { 
       SAFE_FREE(ident);
       /* Create the session on first server's cleartext packet */
       if(!memcmp(PACKET->DATA.data,"SSH-", 4) && FROM_SERVER("ssh", PACKET)) {
@@ -196,7 +199,7 @@ FUNC_DECODER(dissector_ssh)
          PACKET->DATA.disp_len = 0;
 	 
          /* While there are packets to read from the stream */
-         while(read_packet(&crypted_packet, &(session_data->data_buffer[direction])) == ESUCCESS) {        
+         while(read_packet(&crypted_packet, &(session_data->data_buffer[direction])) == E_SUCCESS) {        
             ssh_len = pntol(crypted_packet);
             ssh_mod = 8 - (ssh_len % 8);
 
@@ -576,8 +579,8 @@ static int32 read_packet(u_char **buffer, struct stream_buf *dbuf)
    int32 length, mod;
    
    /* Read packet length and calculate modulus */
-   if (streambuf_read(dbuf, (u_char *)&length, 4, STREAM_ATOMIC) == -EINVALID)
-      return -EINVALID;
+   if (streambuf_read(dbuf, (u_char *)&length, 4, STREAM_ATOMIC) == -E_INVALID)
+      return -E_INVALID;
    length = ntohl(length);   
    mod = 8 - (length % 8);
 
@@ -586,14 +589,14 @@ static int32 read_packet(u_char **buffer, struct stream_buf *dbuf)
     */
    *buffer = (u_char *)malloc(length + mod + 4);
    if (*buffer == NULL)
-      return -EINVALID;
+      return -E_INVALID;
       
-   if (streambuf_get(dbuf, *buffer, length + mod + 4, STREAM_ATOMIC) == -EINVALID) {
+   if (streambuf_get(dbuf, *buffer, length + mod + 4, STREAM_ATOMIC) == -E_INVALID) {
       SAFE_FREE(*buffer);
-      return -EINVALID;
+      return -E_INVALID;
    }
       
-   return ESUCCESS;
+   return E_SUCCESS;
 }
 
 /* 3DES and blowfish stuff - Thanks to Dug Song ;) */
@@ -602,6 +605,8 @@ static void *des3_init(u_char *sesskey, int len)
    struct des3_state *state;
 
    state = malloc(sizeof(*state));
+   if (state == NULL) /* oops, couldn't allocate memory */
+      return NULL;
 
    des_set_key((void *)sesskey, (state->k1));
    des_set_key((void *)(sesskey + 8), (state->k2));
@@ -647,6 +652,8 @@ static void *blowfish_init(u_char *sesskey, int len)
    struct blowfish_state *state;
 
    state = malloc(sizeof(*state));
+   if (state == NULL) /* oops, couldn't allocate memory */
+      return NULL;
    BF_set_key(&state->key, len, sesskey);
    memset(state->iv, 0, 8);
    return (state);
@@ -711,9 +718,15 @@ static void rsa_public_encrypt(BIGNUM *out, BIGNUM *in, RSA *key)
 
    olen = BN_num_bytes(key->n);
    outbuf = malloc(olen);
+   if (outbuf == NULL) /* oops, couldn't allocate memory */
+      return;
 
    ilen = BN_num_bytes(in);
    inbuf = malloc(ilen);
+   if (inbuf == NULL) { /* oops, couldn't allocate memory */
+      SAFE_FREE(outbuf);
+      return;
+   }
 
    BN_bn2bin(in, inbuf);
 
@@ -733,9 +746,15 @@ static void rsa_private_decrypt(BIGNUM *out, BIGNUM *in, RSA *key)
 
    olen = BN_num_bytes(key->n);
    outbuf = malloc(olen);
+   if (outbuf == NULL) /* oops, couldn't allocate memory */
+      return;
 
    ilen = BN_num_bytes(in);
    inbuf = malloc(ilen);
+   if (inbuf == NULL) { /* oops, couldn't allocate memory */
+      SAFE_FREE(outbuf);
+      return;
+   }
 
    BN_bn2bin(in, inbuf);
 
@@ -748,8 +767,6 @@ static void rsa_private_decrypt(BIGNUM *out, BIGNUM *in, RSA *key)
    free(inbuf);
 }
 
-#endif
-
 /* EOF */
 
 // vim:ts=3:expandtab
