@@ -39,6 +39,7 @@ static struct conf_entry privs[] = {
 static struct conf_entry mitm[] = {
    { "arp_storm_delay", NULL },
    { "arp_poison_delay", NULL },
+   { "arp_poison_smart", NULL },
    { "arp_poison_warm_up", NULL },
    { "arp_poison_icmp", NULL },
    { "arp_poison_reply", NULL },
@@ -48,7 +49,12 @@ static struct conf_entry mitm[] = {
    { "port_steal_delay", NULL },
    { "port_steal_send_delay", NULL },
 #ifdef WITH_IPV6
-   { "nadv_poison_send_delay", NULL },
+   { "ndp_poison_warm_up", NULL },
+   { "ndp_poison_delay", NULL },
+   { "ndp_poison_send_delay", NULL },
+   { "ndp_poison_icmp", NULL },
+   { "ndp_poison_equal_mac", NULL},
+   { "icmp6_probe_delay", NULL },
 #endif
    { NULL, NULL },
 };
@@ -74,6 +80,7 @@ static struct conf_entry misc[] = {
    { "checksum_warning", NULL },
    { "checksum_check", NULL },
    { "submit_fingerprint", NULL },
+   { "sniffing_at_startup", NULL },
    { NULL, NULL },
 };
 
@@ -126,9 +133,9 @@ static struct conf_section sections[] = {
 
 /* protos */
 
-void load_conf(void);
 static void init_structures(void);
 static void set_pointer(struct conf_entry *entry, char *name, void *ptr);
+static void sanity_checks(void);
 
 static void set_dissector(char *name, char *values, int lineno);
 static struct conf_entry * search_section(char *title);
@@ -151,6 +158,7 @@ static void init_structures(void)
    set_pointer((struct conf_entry *)&privs, "ec_uid", &GBL_CONF->ec_uid);
    set_pointer((struct conf_entry *)&privs, "ec_gid", &GBL_CONF->ec_gid);
    set_pointer((struct conf_entry *)&mitm, "arp_storm_delay", &GBL_CONF->arp_storm_delay);
+   set_pointer((struct conf_entry *)&mitm, "arp_poison_smart", &GBL_CONF->arp_poison_smart);
    set_pointer((struct conf_entry *)&mitm, "arp_poison_warm_up", &GBL_CONF->arp_poison_warm_up);
    set_pointer((struct conf_entry *)&mitm, "arp_poison_delay", &GBL_CONF->arp_poison_delay);
    set_pointer((struct conf_entry *)&mitm, "arp_poison_icmp", &GBL_CONF->arp_poison_icmp);
@@ -161,7 +169,12 @@ static void init_structures(void)
    set_pointer((struct conf_entry *)&mitm, "port_steal_delay", &GBL_CONF->port_steal_delay);
    set_pointer((struct conf_entry *)&mitm, "port_steal_send_delay", &GBL_CONF->port_steal_send_delay);
 #ifdef WITH_IPV6
-   set_pointer((struct conf_entry *)&mitm, "nadv_poison_send_delay", &GBL_CONF->nadv_poison_send_delay);
+   set_pointer((struct conf_entry *)&mitm, "ndp_poison_warm_up", &GBL_CONF->ndp_poison_warm_up);
+   set_pointer((struct conf_entry *)&mitm, "ndp_poison_delay", &GBL_CONF->ndp_poison_delay);
+   set_pointer((struct conf_entry *)&mitm, "ndp_poison_send_delay", &GBL_CONF->ndp_poison_send_delay);
+   set_pointer((struct conf_entry *)&mitm, "ndp_poison_icmp", &GBL_CONF->ndp_poison_icmp);
+   set_pointer((struct conf_entry *)&mitm, "ndp_poison_equal_mac", &GBL_CONF->ndp_poison_equal_mac);
+   set_pointer((struct conf_entry *)&mitm, "icmp6_probe_delay", &GBL_CONF->icmp6_probe_delay);
 #endif
    set_pointer((struct conf_entry *)&connections, "connection_timeout", &GBL_CONF->connection_timeout);
    set_pointer((struct conf_entry *)&connections, "connection_idle", &GBL_CONF->connection_idle);
@@ -175,6 +188,7 @@ static void init_structures(void)
    set_pointer((struct conf_entry *)&misc, "checksum_warning", &GBL_CONF->checksum_warning);
    set_pointer((struct conf_entry *)&misc, "checksum_check", &GBL_CONF->checksum_check);
    set_pointer((struct conf_entry *)&misc, "submit_fingerprint", &GBL_CONF->submit_fingerprint);
+   set_pointer((struct conf_entry *)&misc, "sniffing_at_startup", &GBL_CONF->sniffing_at_startup);
    set_pointer((struct conf_entry *)&curses, "color_bg", &GBL_CONF->colors.bg);
    set_pointer((struct conf_entry *)&curses, "color_fg", &GBL_CONF->colors.fg);
    set_pointer((struct conf_entry *)&curses, "color_join1", &GBL_CONF->colors.join1);
@@ -226,6 +240,13 @@ static void set_pointer(struct conf_entry *entry, char *name, void *ptr)
    } while (entry[++i].name != NULL);
 }
 
+static void sanity_checks()
+{
+   // sampling_rate cannot be equal to 0, since we divide by it
+   if (GBL_CONF->sampling_rate == 0)
+      GBL_CONF->sampling_rate = 50;
+}
+
 /*
  * load the configuration from etter.conf file
  */
@@ -236,6 +257,7 @@ void load_conf(void)
    char line[128];
    char *p, *q, **tmp;
    int lineno = 0;
+   size_t tmplen;
    struct conf_entry *curr_section = NULL;
    void *value = NULL;
 
@@ -341,7 +363,7 @@ void load_conf(void)
       /* strings must be handled in a different way */
       if (curr_section == (struct conf_entry *)&strings) {
          /* trim the quotes */
-         if (*p == '\"')
+         if (*p == '"')
             p++;
          
          /* set the string value */ 
@@ -350,10 +372,13 @@ void load_conf(void)
          
          /* trim the ending quotes */
          p = *tmp;
+         tmplen = strlen(*tmp);
          do {
-            if (*p == '\"')
+            if (*p == '"') {
                *p = 0;
-         } while (p++ < *tmp + strlen(*tmp) );
+               break;
+            }
+         } while (p++ < *tmp + tmplen );
          
          DEBUG_MSG("load_conf: \tENTRY: %s  [%s]", q, *tmp);
       } else {
@@ -362,7 +387,8 @@ void load_conf(void)
          DEBUG_MSG("load_conf: \tENTRY: %s  %d", q, *(int *)value);
       }
    }
-  
+
+   sanity_checks();
    fclose(fc);
 }
 
@@ -433,11 +459,11 @@ static void set_dissector(char *name, char *values, int lineno)
     
       /* the first value replaces all the previous */
       if (p == q) {
-         if (dissect_modify(MODE_REP, name, value) != ESUCCESS)
+         if (dissect_modify(MODE_REP, name, value) != E_SUCCESS)
             fprintf(stderr, "Dissector \"%s\" not supported (%s line %d)\n", name, ETTER_CONF, lineno);
       } else {
          /* the other values have to be added */
-         if (dissect_modify(MODE_ADD, name, value) != ESUCCESS)
+         if (dissect_modify(MODE_ADD, name, value) != E_SUCCESS)
             fprintf(stderr, "Dissector \"%s\" not supported (%s line %d)\n", name, ETTER_CONF, lineno);
       }
       
