@@ -13,9 +13,9 @@
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
 
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+    You should have received a copy of the GNU General Public License along
+    with this program; if not, write to the Free Software Foundation, Inc.,
+    51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
 */
 
@@ -42,20 +42,9 @@ static struct log_fd fdi;
 
 /* protos */
 
-int set_loglevel(int level, char *filename);
-int set_msg_loglevel(int level, char *filename);
-
-int log_open(struct log_fd *fd, char *filename);
-void log_close(struct log_fd *fd);
-void log_stop(void);
-
-int log_write_header(struct log_fd *fd, int type);
 
 static void log_packet(struct packet_object *po);
 static void log_info(struct packet_object *po);
-void log_write_packet(struct log_fd *fd, struct packet_object *po);
-void log_write_info(struct log_fd *fd, struct packet_object *po);
-void log_write_info_arp_icmp(struct log_fd *fd, struct packet_object *po);
 
 static pthread_mutex_t log_mutex = PTHREAD_MUTEX_INITIALIZER;
 #define LOG_LOCK     do{ pthread_mutex_lock(&log_mutex); } while(0)
@@ -82,7 +71,7 @@ int set_loglevel(int level, char *filename)
    /* if we want to stop logging, return here */
    if (level == LOG_STOP) {
       DEBUG_MSG("set_loglevel: stopping the log process");
-      return ESUCCESS;
+      return E_SUCCESS;
    }
    
    DEBUG_MSG("set_loglevel(%d, %s)", level, filename); 
@@ -113,8 +102,8 @@ int set_loglevel(int level, char *filename)
          }
          
          /* create the file */
-         if (log_open(&fdp, ecp) != ESUCCESS)
-            return -EFATAL;
+         if (log_open(&fdp, ecp) != E_SUCCESS)
+            return -E_FATAL;
 
          /* initialize the log file */
          log_write_header(&fdp, LOG_PACKET);
@@ -132,8 +121,8 @@ int set_loglevel(int level, char *filename)
          }
          
          /* create the file */
-         if (log_open(&fdi, eci) != ESUCCESS)
-            return -EFATAL;
+         if (log_open(&fdi, eci) != E_SUCCESS)
+            return -E_FATAL;
          
          /* initialize the log file */
          log_write_header(&fdi, LOG_INFO);
@@ -154,9 +143,9 @@ int set_loglevel(int level, char *filename)
          break;
    }
 
-   atexit(&log_stop);
+   atexit(log_stop);
 
-   return ESUCCESS;
+   return E_SUCCESS;
 }
 
 /*
@@ -197,7 +186,7 @@ int log_open(struct log_fd *fd, char *filename)
    /* set the permissions */
    chmod(filename, 0600);
 
-   return ESUCCESS;
+   return E_SUCCESS;
 }
 
 /* 
@@ -457,13 +446,13 @@ void log_write_info(struct log_fd *fd, struct packet_object *po)
 
    /* calculate if the dest is local or not */
    switch (ip_addr_is_local(&po->L3.dst, NULL)) {
-      case ESUCCESS:
+      case E_SUCCESS:
          hid.type |= FP_HOST_LOCAL;
          break;
-      case -ENOTFOUND:
+      case -E_NOTFOUND:
          hid.type |= FP_HOST_NONLOCAL;
          break;
-      case -EINVALID:
+      case -E_INVALID:
          hid.type = FP_UNKNOWN;
          break;
    }
@@ -646,7 +635,7 @@ int set_msg_loglevel(int level, char *filename)
          break;
    }
 
-   return ESUCCESS;
+   return E_SUCCESS;
 }
 
 /* EOF */
