@@ -21,6 +21,7 @@
 
 
 #include <ec.h>
+#include <ec_parser.h>
 #include <ec_interfaces.h>
 #include <ec_sniff.h>
 #include <ec_send.h>
@@ -47,57 +48,6 @@
 /* protos... */
 
 static void ec_usage(void);
-void parse_options(int argc, char **argv);
-
-int expand_token(char *s, u_int max, void (*func)(void *t, u_int n), void *t );
-int set_regex(char *regex);
-static char **parse_iflist(char *list);
-
-/* set functions */
-void set_mitm(char *mitm);
-void set_onlymitm(void);
-void set_broadcast(void);
-void set_iface_bridge(char *iface);
-void set_promisc(void);
-void set_reversed(void);
-void set_proto(char *arg);
-void set_plugin(char *plugin);
-void set_iface(char *iface);
-void set_lifaces(void);
-void set_secondary(char *iface);
-void set_netmask(char *netmask);
-void set_address(char *address);
-void set_read_pcap(char *pcap_file);
-void set_write_pcap(char *pcap_file);
-void set_pcap_filter(char *filter);
-void load_filter(char *end, char *filter);
-void set_loglevel_packet(char *arg);
-void set_loglevel_info(char *arg);
-void set_loglevel_true(char *arg);
-void set_compress(void);
-void opt_set_regex(char *regex);
-void set_quiet(void);
-void set_superquiet(void);
-void set_script(char *script);
-void set_silent(void);
-void set_unoffensive(void);
-void disable_sslmitm(void);
-void set_resolve(void);
-void load_hosts(char *file);
-void save_hosts(char *file);
-void opt_set_format(char *format);
-void set_ext_headers(void);
-void set_wifi_key(char *key);
-void set_conf_file(char *file);
-void set_ssl_cert(char *cert);
-void set_ssl_key(char *key);
-#ifdef HAVE_EC_LUA
-void set_lua_args(char *args);
-void set_lua_script(char *script);
-#endif
-void set_target_target1(char *target1);
-void set_target_target2(char *target2);
-
 
 /*****************************************/
 
@@ -166,6 +116,9 @@ void ec_usage(void)
    fprintf(stdout, "  -P, --plugin <plugin>       launch this <plugin>\n");
    fprintf(stdout, "  -F, --filter <file>         load the filter <file> (content filter)\n");
    fprintf(stdout, "  -z, --silent                do not perform the initial ARP scan\n");
+#ifdef WITH_IPV6
+   fprintf(stdout, "  -6, --ip6scan               send ICMPv6 probes to discover IPv6 nodes on the link\n");
+#endif
    fprintf(stdout, "  -j, --load-hosts <file>     load the hosts list from <file>\n");
    fprintf(stdout, "  -k, --save-hosts <file>     save the hosts list to <file>\n");
    fprintf(stdout, "  -W, --wifi-key <wkey>       use this key to decrypt wifi packets (wep or wpa)\n");
@@ -213,6 +166,9 @@ void parse_options(int argc, char **argv)
       { "quiet", no_argument, NULL, 'q' },
       { "script", required_argument, NULL, 's' },
       { "silent", no_argument, NULL, 'z' },
+#ifdef WITH_IPV6
+      { "ip6scan", no_argument, NULL, '6' },
+#endif
       { "unoffensive", no_argument, NULL, 'u' },
       { "nosslmitm", no_argument, NULL, 'S' },
       { "load-hosts", required_argument, NULL, 'j' },
@@ -267,7 +223,7 @@ void parse_options(int argc, char **argv)
    optind = 0;
    int option_index = 0;
 
-   while ((c = getopt_long (argc, argv, "A:a:bB:CchDdEe:F:f:GhIi:j:k:L:l:M:m:n:oP:pQqiRr:s:STt:uV:vW:w:Y:z", long_options, &option_index)) != EOF) {
+   while ((c = getopt_long (argc, argv, "A:a:bB:CchDdEe:F:f:GhIi:j:k:L:l:M:m:n:oP:pQqiRr:s:STt:uV:vW:w:Y:z6", long_options, &option_index)) != EOF) {
       /* used for parsing arguments */
       char *opt_end = optarg;
       while (opt_end && *opt_end) opt_end++;
@@ -327,12 +283,13 @@ void parse_options(int argc, char **argv)
                   break;
                   
          case 'i':
-		  set_iface(optarg);
+  set_iface(optarg);
                   break;
                   
          case 'I':
                   /* this option is only useful in the text interface */
-	          set_lifaces();
+          set_lifaces();
+  select_text_interface();
                   break;
 
          case 'Y':
@@ -360,7 +317,7 @@ void parse_options(int argc, char **argv)
                   break;
                   
          case 'F':
-		  load_filter(opt_end, optarg);
+		  set_filter(opt_end, optarg);
                   break;
                   
          case 'L':
@@ -397,6 +354,12 @@ void parse_options(int argc, char **argv)
                   set_silent();
                   break;
                   
+#ifdef WITH_IPV6
+         case '6':
+                  set_ip6scan();
+                  break;
+#endif
+
          case 'u':
                   set_unoffensive();
                   break;
@@ -410,11 +373,11 @@ void parse_options(int argc, char **argv)
                   break;
                   
          case 'j':
-                  load_hosts(optarg);
+                  set_load_hosts(optarg);
                   break;
                   
          case 'k':
-	          save_hosts(optarg);
+	          set_save_hosts(optarg);
                   break;
                   
          case 'V':
@@ -541,359 +504,6 @@ void parse_options(int argc, char **argv)
    return;
 }
 
-
-/*
- * This function parses the input in the form [1-3,17,5-11]
- * and fill the structure with expanded numbers.
- */
-
-int expand_token(char *s, u_int max, void (*func)(void *t, u_int n), void *t )
-{
-   char *str = strdup(s);
-   char *p, *q, r;
-   char *end;
-   u_int a = 0, b = 0;
-   
-   DEBUG_MSG("expand_token %s", s);
-   
-   p = str;
-   end = p + strlen(p);
-   
-   while (p < end) {
-      q = p;
-      
-      /* find the end of the first digit */
-      while ( isdigit((int)*q) && q++ < end);
-      
-      r = *q;   
-      *q = 0;
-      /* get the first digit */
-      a = atoi(p);
-      if (a > max) 
-         FATAL_MSG("Out of range (%d) !!", max);
-      
-      /* it is a range ? */
-      if ( r == '-') {
-         p = ++q;
-         /* find the end of the range */
-         while ( isdigit((int)*q) && q++ < end);
-         *q = 0;
-         if (*p == '\0') 
-            FATAL_MSG("Invalid range !!");
-         /* get the second digit */
-         b = atoi(p);
-         if (b > max) 
-            FATAL_MSG("Out of range (%d)!!", max);
-         if (b < a)
-            FATAL_MSG("Invalid decrementing range !!");
-      } else {
-         /* it is not a range */
-         b = a; 
-      } 
-      
-      /* process the range and invoke the callback */
-      for(; a <= b; a++) {
-         func(t, a);
-      }
-      
-      if (q == end) break;
-      else  p = q + 1;      
-   }
-  
-   SAFE_FREE(str);
-   
-   return ESUCCESS;
-}
-
-/*
- * compile the regex
- */
-
-int set_regex(char *regex)
-{
-   int err;
-   char errbuf[100];
-   
-   DEBUG_MSG("set_regex: %s", regex);
-
-   /* free any previous compilation */
-   if (GBL_OPTIONS->regex)
-      regfree(GBL_OPTIONS->regex);
-
-   /* unset the regex if empty */
-   if (!strcmp(regex, "")) {
-      SAFE_FREE(GBL_OPTIONS->regex);
-      return ESUCCESS;
-   }
-  
-   /* allocate the new structure */
-   SAFE_CALLOC(GBL_OPTIONS->regex, 1, sizeof(regex_t));
-  
-   /* compile the regex */
-   err = regcomp(GBL_OPTIONS->regex, regex, REG_EXTENDED | REG_NOSUB | REG_ICASE );
-
-   if (err) {
-      regerror(err, GBL_OPTIONS->regex, errbuf, sizeof(errbuf));
-      FATAL_MSG("%s\n", errbuf);
-   }
-
-   return ESUCCESS;
-}
-
-static char **parse_iflist(char *list)
-{
-   int i, n;
-   char **r, *t, *p;
-
-   for(i = 0, n = 1; list[i] != '\0'; list[i++] == ',' ? n++ : n);
-   SAFE_CALLOC(r, n + 1, sizeof(char*));
-
-   /* its self-explaining */
-   for(r[i=0]=ec_strtok(list,",",&p);i<n&&(t=ec_strtok(NULL,",",&p))!=NULL;r[++i]=strdup(t));
-   r[n] = NULL;
-
-   return r;
-}
-
-/* set functions */
-void set_mitm(char *mitm) 
-{
-	GBL_OPTIONS->mitm = 1;
-	if(mitm_set(mitm) != ESUCCESS)
-		FATAL_ERROR("MiTM method '%s' not supported...\n", mitm);
-}
-
-void set_onlymitm(void)
-{
-	GBL_OPTIONS->only_mitm = 1;
-}
-
-void set_broadcast(void)
-{
-	GBL_OPTIONS->broadcast = 1;
-}
-
-void set_iface_bridge(char *iface)
-{
-	GBL_OPTIONS->iface_bridge = strdup(iface);
-	set_bridge_sniff();
-}
-
-void set_promisc(void)
-{
-	GBL_PCAP->promisc = 0;
-}
-
-void set_reversed(void)
-{
-	GBL_OPTIONS->reversed = 1;
-}
-
-void set_plugin(char *plugin)
-{
-	if(!strcasecmp(plugin, "list")) {
-		plugin_list();
-		clean_exit(0);
-	}
-
-	GBL_OPTIONS->plugin = strdup(plugin);
-}
-
-void set_proto(char *proto)
-{
-	GBL_OPTIONS->proto = strdup(proto);
-}
-
-void set_iface(char *iface)
-{
-	GBL_OPTIONS->iface = strdup(iface);
-}
-
-void set_lifaces(void)
-{
-#ifndef JUST_LIBRARY
-	GBL_OPTIONS->lifaces = 1;
-	select_text_interface();
-#endif
-}
-
-void set_secondary(char *iface)
-{
-	GBL_OPTIONS->secondary = parse_iflist(iface);
-}
-
-void set_netmask(char *netmask)
-{
-	GBL_OPTIONS->netmask = strdup(netmask);
-}
-
-void set_address(char *address)
-{
-	GBL_OPTIONS->address = strdup(address);
-}
-
-void set_read_pcap(char *pcap_file)
-{
-	/* we don't want to scan th eLAN while reading from file */
-	GBL_OPTIONS->silent = 1;
-	GBL_OPTIONS->read = 1;
-	GBL_OPTIONS->pcapfile_in = strdup(pcap_file);
-}
-
-void set_write_pcap(char *pcap_file)
-{
-	GBL_OPTIONS->write = 1;
-	GBL_OPTIONS->pcapfile_out = strdup(pcap_file);
-}
-
-void set_pcap_filter(char *filter)
-{
-	GBL_PCAP->filter = strdup(filter);
-}
-
-void load_filter(char *end, char *filter)
-{
-	uint8_t f_enabled = 1;
-	if ( (end-filter >=2) && *(end-2) == ':') {
-		*(end-2) = '\0';
-		f_enabled = !( *(end-1) == '0' );
-	}	
-	
-	if (filter_load_file(filter, GBL_FILTERS, f_enabled) != ESUCCESS)
-		FATAL_ERROR("Cannot load filter file \"%s\"", filter);
-}
-
-
-void set_loglevel_packet(char *arg)
-{
-	if (set_loglevel(LOG_PACKET, arg) == -EFATAL)
-		clean_exit(-EFATAL);
-}
-
-void set_loglevel_info(char *arg)
-{
-	if (set_loglevel(LOG_INFO, arg) == -EFATAL)
-		clean_exit(-EFATAL);
-}
-
-void set_loglevel_true(char *arg)
-{
-	if (set_msg_loglevel(LOG_TRUE, arg) == -EFATAL)
-		clean_exit(-EFATAL);
-}
-
-void set_compress(void)
-{
-	GBL_OPTIONS->compress = 1;
-}
-
-void opt_set_regex(char *regex)
-{
-	if (set_regex(regex) == -EFATAL)
-		clean_exit(-EFATAL);
-}
-
-void set_superquiet()
-{
-	GBL_OPTIONS->superquiet = 1;
-}
-
-void set_quiet(void)
-{
-	GBL_OPTIONS->quiet = 1;
-}
-
-void set_script(char *script)
-{
-	GBL_OPTIONS->script = strdup(script);
-}
-
-void set_silent(void)
-{
-	GBL_OPTIONS->silent = 1;
-}
-
-void set_unoffensive(void)
-{
-	GBL_OPTIONS->unoffensive = 1;
-}
-
-void disable_sslmitm(void)
-{
-	GBL_OPTIONS->ssl_mitm = 0;
-}
-
-void set_resolve(void)
-{
-	GBL_OPTIONS->resolve = 1;
-}
-
-void load_hosts(char *file)
-{
-	GBL_OPTIONS->silent = 1;
-	GBL_OPTIONS->load_hosts = 1;
-	GBL_OPTIONS->hostsfile = strdup(file);
-}
-
-void save_hosts(char *file)
-{
-	GBL_OPTIONS->save_hosts = 1;
-	GBL_OPTIONS->hostsfile = strdup(file);
-}
-
-void opt_set_format(char *format)
-{
-	if (set_format(format) != ESUCCESS)
-		clean_exit(-EFATAL);	
-}
-
-void set_ext_headers(void)
-{
-	GBL_OPTIONS->ext_headers = 1;
-}
-
-void set_wifi_key(char *key)
-{
-	wifi_key_prepare(key);
-}
-
-void set_conf_file(char *file)
-{
-	GBL_CONF->file = strdup(file);
-}
-
-void set_ssl_cert(char *cert)
-{
-	GBL_OPTIONS->ssl_cert = strdup(cert);
-}
-
-void set_ssl_key(char *key)
-{
-	GBL_OPTIONS->ssl_pkey = strdup(key);
-}
-
-#ifdef HAVE_EC_LUA
-void set_lua_args(char *args)
-{
-	ec_lua_cli_add_args(strdup(args));
-}
-
-void set_lua_script(char *script)
-{
-	ec_lua_cli_add_script(strdup(script));
-}
-#endif
-
-void set_target_target1(char *target1)
-{
-	GBL_OPTIONS->target1 = strdup(target1);
-}
-
-void set_target_target2(char *target2)
-{
-	GBL_OPTIONS->target2 = strdup(target2);
-}
-
 /* EOF */
 
 
