@@ -56,20 +56,22 @@ struct plugin_entry {
 
 static SLIST_HEAD(, plugin_entry) plugin_head;
 
+/* mutexes */
+static pthread_mutex_t kill_mutex = PTHREAD_MUTEX_INITIALIZER;
+#define KILL_LOCK do { pthread_mutex_lock(&kill_mutex); } while (0)
+#define KILL_UNLOCK do { pthread_mutex_unlock(&kill_mutex); } while (0)
+
+static pthread_mutex_t plugin_list_mutex = PTHREAD_MUTEX_INITIALIZER;
+#define PLUGIN_LIST_LOCK do { pthread_mutex_lock(&plugin_list_mutex); } \
+                         while (0)
+#define PLUGIN_LIST_UNLOCK do { pthread_mutex_unlock(&plugin_list_mutex); } \
+                           while (0)
+
 /* protos... */
 
-void plugin_load_all(void);
 void plugin_unload_all(void);
-int plugin_load_single(char *path, char *name);
-int plugin_register(void *handle, struct plugin_ops *ops);
-int plugin_init(char *name);
-int plugin_fini(char *name);
-int plugin_list_walk(int min, int max, void (*func)(char, struct plugin_ops *));
-int plugin_is_activated(char *name);
-int search_plugin(char *name);
-void plugin_list(void);
 static void plugin_print(char active, struct plugin_ops *ops);
-#if defined(OS_BSD) || defined (OS_DARWIN)
+#if defined (OS_DARWIN)
 int plugin_filter(struct dirent *d);
 #else
 int plugin_filter(const struct dirent *d);
@@ -81,7 +83,7 @@ int plugin_filter(const struct dirent *d);
  * load a plugin given the full path
  */
 
-int plugin_load_single(char *path, char *name)
+int plugin_load_single(const char *path, char *name)
 {
 #ifdef HAVE_PLUGINS
    char file[strlen(path)+strlen(name)+2];
@@ -97,7 +99,7 @@ int plugin_load_single(char *path, char *name)
 
    if (handle == NULL) {
       DEBUG_MSG("plugin_load_single - %s - dlopen() | %s", file, dlerror());
-      return -EINVALID;
+      return -E_INVALID;
    }
    
    /* find the loading function */
@@ -106,7 +108,7 @@ int plugin_load_single(char *path, char *name)
    if (plugin_load == NULL) {
       DEBUG_MSG("plugin_load_single - %s - lt_dlsym() | %s", file, dlerror());
       dlclose(handle);
-      return -EINVALID;
+      return -E_INVALID;
    }
 
    /* 
@@ -117,14 +119,16 @@ int plugin_load_single(char *path, char *name)
     */
    return plugin_load(handle);
 #else
-   return -EINVALID;
+   (void) path;
+   (void) name;
+   return -E_INVALID;
 #endif
 }
 
 /*
  * filter for the scandir function
  */
-#if defined(OS_BSD) || defined (OS_DARWIN)
+#if defined (OS_DARWIN)
 int plugin_filter(struct dirent *d)
 #else
 int plugin_filter(const struct dirent *d)
@@ -169,7 +173,7 @@ void plugin_load_all(void)
    if (n <= 0) {
       DEBUG_MSG("plugin_loadall: no plugin in %s searching locally...", where);
       /* change the path to the local one */
-      where = ".";
+      where = "plug-ins";
       n = scandir(where, &namelist, plugin_filter, alphasort);
       DEBUG_MSG("plugin_loadall: %d found", n);
    }
@@ -177,18 +181,18 @@ void plugin_load_all(void)
    for(i = n-1; i >= 0; i--) {
       ret = plugin_load_single(where, namelist[i]->d_name);
       switch (ret) {
-         case ESUCCESS:
+         case E_SUCCESS:
             t++;
             break;
-         case -EDUPLICATE:
+         case -E_DUPLICATE:
             USER_MSG("plugin %s already loaded...\n", namelist[i]->d_name);
             DEBUG_MSG("plugin %s already loaded...", namelist[i]->d_name);
             break;
-         case -EVERSION:
+         case -E_VERSION:
             USER_MSG("plugin %s was compiled for a different ettercap version...\n", namelist[i]->d_name);
             DEBUG_MSG("plugin %s was compiled for a different ettercap version...", namelist[i]->d_name);
             break;
-         case -EINVALID:
+         case -E_INVALID:
          default:
             USER_MSG("plugin %s cannot be loaded...\n", namelist[i]->d_name);
             DEBUG_MSG("plugin %s cannot be loaded...", namelist[i]->d_name);
@@ -241,7 +245,7 @@ int plugin_register(void *handle, struct plugin_ops *ops)
    /* check for ettercap API version */
    if (strcmp(ops->ettercap_version, EC_VERSION)) {
       dlclose(handle);
-      return -EVERSION;
+      return -E_VERSION;
    }
    
    /* check that this plugin was not already loaded */
@@ -249,7 +253,7 @@ int plugin_register(void *handle, struct plugin_ops *ops)
       /* same name and same version */
       if (!strcmp(ops->name, pl->ops->name) && !strcmp(ops->version, pl->ops->version)) {
          dlclose(handle);
-         return -EDUPLICATE;
+         return -E_DUPLICATE;
       }
    }
 
@@ -260,9 +264,11 @@ int plugin_register(void *handle, struct plugin_ops *ops)
 
    SLIST_INSERT_HEAD(&plugin_head, p, next);
 
-   return ESUCCESS;
+   return E_SUCCESS;
 #else
-   return -EINVALID;
+   (void) handle;
+   (void) ops;
+   return -E_INVALID;
 #endif
 }
 
@@ -287,7 +293,7 @@ int plugin_init(char *name)
       }
    }
    
-   return -ENOTFOUND;
+   return -E_NOTFOUND;
 }
 
 
@@ -311,7 +317,58 @@ int plugin_fini(char *name)
       }
    }
    
-   return -ENOTFOUND;
+   return -E_NOTFOUND;
+}
+
+/* 
+ * self-destruct a plugin thread.
+ * it resets the activity state and destructs itself by calling the plugin fini function.
+ * it does not replace the <plugin>_fini standard function rather than it depends on it.
+ * this function does not do anything if not executed by a thread.
+ */
+int plugin_kill_thread(char *name, char *thread)
+{
+   struct plugin_entry *p;
+   int ret;
+   pthread_t pid;
+
+   pid = ec_thread_getpid(thread); 
+
+   /* do not execute if not being a thread */
+   if (pthread_equal(pid, EC_PTHREAD_NULL))
+      return -E_INVALID;
+
+   /* the thread can only kill itself */
+   if (!pthread_equal(pid, pthread_self()))
+      return -E_INVALID;
+
+   DEBUG_MSG("plugin_kill_thread");
+
+   KILL_LOCK;
+   SLIST_FOREACH(p, &plugin_head, next) {
+      if (p->activated == 1 && !strcmp(p->ops->name, name)) {
+         /* flag plugin as inactive */
+         p->activated = 0;
+         /* update the UI */
+         ui_update(UI_UPDATE_PLUGINLIST);
+         /* release the lock */
+         KILL_UNLOCK;
+         /* call plugin's destruction routine */
+         ret = p->ops->fini(NULL);
+         /*
+          * normally the thread should not return from the call - 
+          * just in case the thread wasn't destroyed in the fini callback
+          * destroy it here 
+          */
+         ec_thread_destroy(pid);
+
+         /* should never be reached */
+         return ret;
+      }
+   }
+   KILL_UNLOCK;
+   
+   return -E_NOTFOUND;
 }
 
 /*
@@ -342,7 +399,7 @@ int plugin_list_walk(int min, int max, void (*func)(char, struct plugin_ops *))
       i++;
    }
    
-   return (i == min) ? -ENOTFOUND : (i-1);
+   return (i == min) ? -E_NOTFOUND : (i-1);
 }
 
 /*
@@ -371,11 +428,11 @@ int search_plugin(char *name)
 
    SLIST_FOREACH(p, &plugin_head, next) {
       if (!strcmp(p->ops->name, name)) {
-         return ESUCCESS;
+         return E_SUCCESS;
       }
    }
    
-   return -ENOTFOUND;
+   return -E_NOTFOUND;
 }
 
 /*
@@ -393,7 +450,7 @@ void plugin_list(void)
    /* print the list */
    fprintf(stdout, "\nAvailable plugins :\n\n");
    ret = plugin_list_walk(PLP_MIN, PLP_MAX, &plugin_print);
-   if (ret == -ENOTFOUND) {
+   if (ret == -E_NOTFOUND) {
       fprintf(stdout, "No plugin found !\n\n");
       return;
    }
@@ -401,11 +458,32 @@ void plugin_list(void)
 
 }
 
+/*
+ * walk through the list of plugin names and free
+ */
+void free_plugin_list(struct plugin_list_t plugins)
+{
+   struct plugin_list *plugin, *tmp;
+
+   PLUGIN_LIST_LOCK;
+
+   LIST_FOREACH_SAFE(plugin, &plugins, next, tmp) {
+      LIST_REMOVE(plugin, next);
+      SAFE_FREE(plugin->name);
+      SAFE_FREE(plugin);
+   }
+
+   PLUGIN_LIST_UNLOCK;
+}
+
 /*
  * callback function for displaying the plugin list 
  */
 static void plugin_print(char active, struct plugin_ops *ops)
 {
+   /* variable not used */
+   (void) active;
+
    fprintf(stdout, " %15s %4s  %s\n", ops->name, ops->version, ops->info);  
 }
 
