@@ -29,6 +29,8 @@
 #include <ec_file.h>
 #include <ec_version.h>
 #include <ec_socket.h>
+#include <ec_utils.h>
+#include <ec_sleep.h>
 
 #include <sys/types.h>
 #ifndef OS_WINDOWS
@@ -40,11 +42,8 @@
 #endif
 
 #include <fcntl.h>
-#include <time.h>
 #include <pthread.h>
 
-#ifdef HAVE_OPENSSL
-
 // XXX - check if we have poll.h
 #ifdef HAVE_SYS_POLL_H
    #include <sys/poll.h>
@@ -55,7 +54,7 @@
 #include <openssl/ssl.h>
 
 #define BREAK_ON_ERROR(x,y,z) do {  \
-   if (x == -EINVALID) {            \
+   if (x == -E_INVALID) {            \
       SAFE_FREE(z.DATA.disp_data);  \
       sslw_initialize_po(&z, z.DATA.data); \
       z.len = 64;                   \
@@ -69,8 +68,6 @@
    }                                \
 } while(0)
 
-#endif /* HAVE_OPENSSL */
-
 /* globals */
 
 static LIST_HEAD (, listen_entry) listen_ports;
@@ -84,9 +81,6 @@ struct listen_entry {
    LIST_ENTRY (listen_entry) next;
 };
 
-
-#ifdef HAVE_OPENSSL
-
 struct accepted_entry {
    int32 fd[2];   /* 0->Client, 1->Server */
    u_int16 port[2];
@@ -124,17 +118,6 @@ static EVP_PKEY *global_pk;
 static u_int16 number_of_services;
 static struct pollfd *poll_fd = NULL;
 
-#endif /* HAVE_OPENSSL */
-
-/* protos */
-
-void sslw_dissect_add(char *name, u_int32 port, FUNC_DECODER_PTR(decoder), u_char status);
-void sslw_dissect_move(char *name, u_int16 port);
-EC_THREAD_FUNC(sslw_start);
-void ssl_wrap_init(void);
-
-#ifdef HAVE_OPENSSL
-
 static EC_THREAD_FUNC(sslw_child);
 static int sslw_is_ssl(struct packet_object *po);
 static int sslw_connect_server(struct accepted_entry *ae);
@@ -158,8 +141,6 @@ static int sslw_ssl_connect(SSL *ssl_sk);
 static int sslw_ssl_accept(SSL *ssl_sk);
 static int sslw_remove_sts(struct packet_object *po);
 
-#endif /* HAVE_OPENSSL */
-
 /*******************************************/
 
 /* 
@@ -208,13 +189,6 @@ void ssl_wrap_init(void)
 {
    struct listen_entry *le;
 
-#ifndef HAVE_OPENSSL
-   /* avoid gcc warning about unused variable */
-   (void)le;
-   
-   DEBUG_MSG("ssl_wrap_init: not supported");
-   return;
-#else
    /* disable if the aggressive flag is not set */
    if (!GBL_CONF->aggressive_dissectors) {
       DEBUG_MSG("ssl_wrap_init: not aggressive");
@@ -242,11 +216,9 @@ void ssl_wrap_init(void)
    SAFE_CALLOC(poll_fd, 1, sizeof(struct pollfd) * number_of_services);
 
    atexit(ssl_wrap_fini);
-#endif
 }
 
 
-#ifdef HAVE_OPENSSL
 static void ssl_wrap_fini(void)
 {
    struct listen_entry *le, *old;
@@ -263,27 +235,22 @@ static void ssl_wrap_fini(void)
    SSL_CTX_free(ssl_ctx_client);
 
 }
-#endif
 
 /* 
  * SSL thread main function.
  */
 EC_THREAD_FUNC(sslw_start)
 {
-#ifdef HAVE_OPENSSL
    struct listen_entry *le;
    struct accepted_entry *ae;
    u_int len = sizeof(struct sockaddr_in), i;
    struct sockaddr_in client_sin;
-#endif
+
+   /* variable not used */
+   (void) EC_THREAD_PARAM;
 
    ec_thread_init();
 
-#ifndef HAVE_OPENSSL
-   DEBUG_MSG("sslw_start: openssl support not compiled in");
-   return NULL;
-#else
-   
    /* disabled if not aggressive */
    if (!GBL_CONF->aggressive_dissectors)
       return NULL;
@@ -339,12 +306,9 @@ EC_THREAD_FUNC(sslw_start)
    }
 
    return NULL;
-#endif /* HAVE_OPENSSL */
    
 }	 
 
-#ifdef HAVE_OPENSSL
-
 /* 
  * Filter SSL related packets and create NAT sessions.
  * It hooks HOOK_HANDLED.
@@ -393,8 +357,8 @@ static int sslw_insert_redirect(u_int16 sport, u_int16 dport)
    /* the script is not defined */
    if (GBL_CONF->redir_command_on == NULL)
    {
-      USER_MSG("SSLStrip: cannot setup the redirect, did you uncomment the redir_command_on command on your etter.conf file?");
-      return -EFATAL;
+      USER_MSG("SSLStrip: cannot setup the redirect, did you uncomment the redir_command_on command on your etter.conf file?\n");
+      return -E_FATAL;
    }
    snprintf(asc_sport, 16, "%u", sport);
    snprintf(asc_dport, 16, "%u", dport);
@@ -428,21 +392,25 @@ static int sslw_insert_redirect(u_int16 sport, u_int16 dport)
    /* execute the script */ 
    switch (fork()) {
       case 0:
+         regain_privs();
          execvp(param[0], param);
+         drop_privs();
          WARN_MSG("Cannot setup http redirect (command: %s), please edit your etter.conf file and put a valid value in redir_command_on field\n", param[0]);
          safe_free_mem(param, &param_length, command);
-         _exit(EINVALID);
+         _exit(-E_INVALID);
       case -1:
          safe_free_mem(param, &param_length, command);
-         return -EINVALID;
+         return -E_INVALID;
       default:
          safe_free_mem(param, &param_length, command);
          wait(&ret_val);
-         if (ret_val == EINVALID)
-            return -EINVALID;
+         if (WIFEXITED(ret_val) && WEXITSTATUS(ret_val)) {
+            USER_MSG("sslwrap: redir_command_on had non-zero exit status (%d): [%s]\n", WEXITSTATUS(ret_val), command);
+            return -E_INVALID;
+         }
    }    
    
-   return ESUCCESS;
+   return E_SUCCESS;
 }
 
 /*
@@ -461,7 +429,7 @@ static int sslw_remove_redirect(u_int16 sport, u_int16 dport)
    if (GBL_CONF->redir_command_off == NULL)
    {
       USER_MSG("SSLStrip: cannot remove the redirect, did you uncomment the redir_command_off command on your etter.conf file?");
-      return -EFATAL;
+      return -E_FATAL;
    }
 
    snprintf(asc_sport, 16, "%u", sport);
@@ -496,21 +464,23 @@ static int sslw_remove_redirect(u_int16 sport, u_int16 dport)
    /* execute the script */ 
    switch (fork()) {
       case 0:
+         regain_privs();
          execvp(param[0], param);
+         drop_privs();
          WARN_MSG("Cannot remove http redirect (command: %s), please edit your etter.conf file and put a valid value in redir_command_on field\n", param[0]);
          safe_free_mem(param, &param_length, command);
-         _exit(EINVALID);
+         _exit(-E_INVALID);
       case -1:
          safe_free_mem(param, &param_length, command);
-         return -EINVALID;
+         return -E_INVALID;
       default:
          safe_free_mem(param, &param_length, command);
          wait(&ret_val);
-         if (ret_val == EINVALID)
-            return -EINVALID;
+         if (ret_val == -E_INVALID)
+            return -E_INVALID;
    }    
    
-   return ESUCCESS;
+   return E_SUCCESS;
 }
 
 
@@ -548,7 +518,8 @@ static void sslw_bind_wrapper(void)
    LIST_FOREACH(le, &listen_ports, next) { 
    
       le->fd = socket(AF_INET, SOCK_STREAM, 0);
-
+      if (le->fd == -1)
+        FATAL_ERROR("Unable to create socket in sslw_bind_wrapper()");
       memset(&sa_in, 0, sizeof(sa_in));
       sa_in.sin_family = AF_INET;
       sa_in.sin_addr.s_addr = INADDR_ANY;
@@ -560,8 +531,9 @@ static void sslw_bind_wrapper(void)
       } while ( bind(le->fd, (struct sockaddr *)&sa_in, sizeof(sa_in)) != 0);
 
       DEBUG_MSG("sslw - bind %d on %d", le->sslw_port, le->redir_port);
-      listen(le->fd, 100);      
-      if (sslw_insert_redirect(le->sslw_port, le->redir_port) != ESUCCESS)
+      if(listen(le->fd, 100) == -1)
+        FATAL_ERROR("Unable to accept connections for socket");      
+      if (sslw_insert_redirect(le->sslw_port, le->redir_port) != E_SUCCESS)
         FATAL_ERROR("Can't insert firewall redirects");
    }
 }
@@ -571,17 +543,17 @@ static void sslw_bind_wrapper(void)
  */
 static int sslw_sync_conn(struct accepted_entry *ae)
 {      
-   if(sslw_get_peer(ae) != ESUCCESS)
-         return -EINVALID;
+   if(sslw_get_peer(ae) != E_SUCCESS)
+         return -E_INVALID;
 	 
-   if(sslw_connect_server(ae) != ESUCCESS)
-         return -EINVALID;
+   if(sslw_connect_server(ae) != E_SUCCESS)
+         return -E_INVALID;
 
    /* set nonbloking socket */
    set_blocking(ae->fd[SSL_CLIENT], 0);
    set_blocking(ae->fd[SSL_SERVER], 0);
 
-   return ESUCCESS;
+   return E_SUCCESS;
 }
 
 
@@ -594,32 +566,22 @@ static int sslw_ssl_connect(SSL *ssl_sk)
    int loops = (GBL_CONF->connect_timeout * 10e5) / TSLEEP;
    int ret, ssl_err;
 
-#if !defined(OS_WINDOWS)
-   struct timespec tm;
-   tm.tv_sec = 0;
-   tm.tv_nsec = TSLEEP * 1000;
-#endif
-   
    do {
       /* connect to the server */
       if ( (ret = SSL_connect(ssl_sk)) == 1)
-         return ESUCCESS;
+         return E_SUCCESS;
 
       ssl_err = SSL_get_error(ssl_sk, ret);
       
       /* there was an error... */
       if (ssl_err != SSL_ERROR_WANT_READ && ssl_err != SSL_ERROR_WANT_WRITE) 
-         return -EINVALID;
+         return -E_INVALID;
       
       /* sleep a quirk of time... */
-#if defined(OS_WINDOWS)
-      usleep(TSLEEP);
-#else
-      nanosleep(&tm, NULL);
-#endif
+      ec_usleep(TSLEEP);
    } while(loops--);
 
-   return -EINVALID;
+   return -E_INVALID;
 }
 
 
@@ -632,32 +594,22 @@ static int sslw_ssl_accept(SSL *ssl_sk)
    int loops = (GBL_CONF->connect_timeout * 10e5) / TSLEEP;
    int ret, ssl_err;
 
-#if !defined(OS_WINDOWS)
-   struct timespec tm;
-   tm.tv_sec = 0;
-   tm.tv_nsec = TSLEEP * 1000;
-#endif
-   
    do {
       /* accept the ssl connection */
       if ( (ret = SSL_accept(ssl_sk)) == 1)
-         return ESUCCESS;
+         return E_SUCCESS;
 
       ssl_err = SSL_get_error(ssl_sk, ret);
       
       /* there was an error... */
       if (ssl_err != SSL_ERROR_WANT_READ && ssl_err != SSL_ERROR_WANT_WRITE) 
-         return -EINVALID;
+         return -E_INVALID;
       
       /* sleep a quirk of time... */
-#if defined(OS_WINDOWS)
-      usleep(TSLEEP);
-#else
-      nanosleep(&tm, NULL);
-#endif
+      ec_usleep(TSLEEP);
    } while(loops--);
 
-   return -EINVALID;
+   return -E_INVALID;
 }
 
 
@@ -678,13 +630,13 @@ static int sslw_sync_ssl(struct accepted_entry *ae)
    ae->ssl[SSL_CLIENT] = SSL_new(ssl_ctx_client);
    SSL_set_fd(ae->ssl[SSL_CLIENT], ae->fd[SSL_CLIENT]);
     
-   if (sslw_ssl_connect(ae->ssl[SSL_SERVER]) != ESUCCESS) 
-      return -EINVALID;
+   if (sslw_ssl_connect(ae->ssl[SSL_SERVER]) != E_SUCCESS) 
+      return -E_INVALID;
 
    /* XXX - NULL cypher can give no certificate */
    if ( (server_cert = SSL_get_peer_certificate(ae->ssl[SSL_SERVER])) == NULL) {
       DEBUG_MSG("Can't get peer certificate");
-      return -EINVALID;
+      return -E_INVALID;
    }
 
    if (!GBL_OPTIONS->ssl_cert) {
@@ -693,17 +645,17 @@ static int sslw_sync_ssl(struct accepted_entry *ae)
    	X509_free(server_cert);
 
    	if (ae->cert == NULL)
-      		return -EINVALID;
+      		return -E_INVALID;
 
    	SSL_use_certificate(ae->ssl[SSL_CLIENT], ae->cert);
 
    }
    
-   if (sslw_ssl_accept(ae->ssl[SSL_CLIENT]) != ESUCCESS) 
-      return -EINVALID;
+   if (sslw_ssl_accept(ae->ssl[SSL_CLIENT]) != E_SUCCESS) 
+      return -E_INVALID;
 
 
-   return ESUCCESS;   
+   return E_SUCCESS;   
 }
 
 
@@ -730,26 +682,16 @@ static int sslw_get_peer(struct accepted_entry *ae)
    
    sslw_create_ident(&ident, &po);
 
-#if !defined(OS_WINDOWS)
-   struct timespec tm;
-   tm.tv_sec = SSLW_WAIT;
-   tm.tv_nsec = 0;
-#endif
-   
    /* 
     * A little waiting loop because the sniffing thread , 
     * which creates the session, may be slower than this
     */
-   for (i=0; i<SSLW_RETRY && session_get_and_del(&s, ident, SSLW_IDENT_LEN)!=ESUCCESS; i++)
-#if defined(OS_WINDOWS)
-      usleep(SSLW_WAIT);
-#else
-      nanosleep(&tm, NULL); 
-#endif /* OS_WINDOWS */
+   for (i=0; i<SSLW_RETRY && session_get_and_del(&s, ident, SSLW_IDENT_LEN)!=E_SUCCESS; i++)
+      ec_usleep(SEC2MICRO(SSLW_WAIT));
 
    if (i==SSLW_RETRY) {
       SAFE_FREE(ident);
-      return -EINVALID;
+      return -E_INVALID;
    }
    
    /* Remember the server IP address in the sessions */
@@ -766,7 +708,7 @@ static int sslw_get_peer(struct accepted_entry *ae)
 
    ip_addr_init(&(ae->ip[SSL_SERVER]), AF_INET, (u_char *)&(sa_in.sin_addr.s_addr));
 #endif
-   return ESUCCESS;
+   return E_SUCCESS;
 }
 
 
@@ -784,17 +726,17 @@ static int sslw_connect_server(struct accepted_entry *ae)
     * strdup it to avoid race conditions.
     * Btw int_ntoa is not so used in the code.
     */
-   dest_ip = strdup(int_ntoa(ip_addr_to_int32(ae->ip[SSL_SERVER].addr)));
+   dest_ip = strdup(int_ntoa(*ae->ip[SSL_SERVER].addr32));
  
    /* Standard connection to the server */
    if (!dest_ip || (ae->fd[SSL_SERVER] = open_socket(dest_ip, ntohs(ae->port[SSL_SERVER]))) < 0) {
       SAFE_FREE(dest_ip);   
       DEBUG_MSG("Could not open socket");
-      return -EINVALID;
+      return -E_INVALID;
    }
    
    SAFE_FREE(dest_ip);	       
-   return ESUCCESS;   
+   return E_SUCCESS;   
 }
 
 
@@ -818,12 +760,12 @@ static int sslw_read_data(struct accepted_entry *ae, u_int32 direction, struct p
       
       /* XXX - Is it necessary? */
       if (len == 0)
-         return -EINVALID;
+         return -E_INVALID;
 	       
       if (ret_err == SSL_ERROR_WANT_READ || ret_err == SSL_ERROR_WANT_WRITE)
-         return -ENOTHANDLED;
+         return -E_NOTHANDLED;
       else
-         return -EINVALID;
+         return -E_INVALID;
    }
 
    /* Only if no ssl */
@@ -831,14 +773,14 @@ static int sslw_read_data(struct accepted_entry *ae, u_int32 direction, struct p
       int err = GET_SOCK_ERRNO();
 
       if (err == EINTR || err == EAGAIN)
-         return -ENOTHANDLED;
+         return -E_NOTHANDLED;
       else
-         return -EINVALID;
+         return -E_INVALID;
    }      
 
    /* XXX - On standard reads, close is 0? (EOF)*/
    if (len == 0) 
-      return -EINVALID;
+      return -E_INVALID;
 
    po->len = len;
    po->DATA.len = len;
@@ -855,7 +797,7 @@ static int sslw_read_data(struct accepted_entry *ae, u_int32 direction, struct p
    packet_destroy_object(po);
    packet_disp_data(po, po->DATA.data, po->DATA.len);
    
-   return ESUCCESS;
+   return E_SUCCESS;
 }
 
 
@@ -871,16 +813,8 @@ static int sslw_write_data(struct accepted_entry *ae, u_int32 direction, struct
    packet_len = (int32)(po->DATA.len + po->DATA.inject_len);
    p_data = po->DATA.data;
 
-#if !defined(OS_WINDOWS)
-   struct timespec tm;
-   tm.tv_sec = 1;
-   tm.tv_nsec = 0;
-#else
-   int timeout = 1000;
-#endif
-   
    if (packet_len == 0)
-      return ESUCCESS;
+      return E_SUCCESS;
 
    do {
       not_written = 0;
@@ -896,7 +830,7 @@ static int sslw_write_data(struct accepted_entry *ae, u_int32 direction, struct
          if (ret_err == SSL_ERROR_WANT_READ || ret_err == SSL_ERROR_WANT_WRITE)
             not_written = 1;
          else
-            return -EINVALID;
+            return -E_INVALID;
       }
 
       if (len < 0 && !(ae->status & SSL_ENABLED)) {
@@ -905,7 +839,7 @@ static int sslw_write_data(struct accepted_entry *ae, u_int32 direction, struct
          if (err == EINTR || err == EAGAIN)
             not_written = 1;
          else
-            return -EINVALID;
+            return -E_INVALID;
       }      
 
       /* XXX - does some OS use partial writes for SSL? */
@@ -918,15 +852,11 @@ static int sslw_write_data(struct accepted_entry *ae, u_int32 direction, struct
       
       /* XXX - Set a proper sleep time */
       if (not_written)
-#if defined(OS_WINDOWS)
-         usleep(timeout);
-#else
-         nanosleep(&tm, NULL);
-#endif
+         ec_usleep(SEC2MICRO(1));
 	 	 
    } while (not_written);
          
-   return ESUCCESS;
+   return E_SUCCESS;
 }
 
 
@@ -959,15 +889,15 @@ static void sslw_parse_packet(struct accepted_entry *ae, u_int32 direction, stru
 
    /* calculate if the dest is local or not */
    switch (ip_addr_is_local(&PACKET->L3.src, NULL)) {
-      case ESUCCESS:
+      case E_SUCCESS:
          PACKET->PASSIVE.flags &= ~FP_HOST_NONLOCAL;
          PACKET->PASSIVE.flags |= FP_HOST_LOCAL;
          break;
-      case -ENOTFOUND:
+      case -E_NOTFOUND:
          PACKET->PASSIVE.flags &= ~FP_HOST_LOCAL;
          PACKET->PASSIVE.flags |= FP_HOST_NONLOCAL;
          break;
-      case -EINVALID:
+      case -E_INVALID:
          PACKET->PASSIVE.flags = FP_UNKNOWN;
          break;
    }
@@ -1138,13 +1068,6 @@ EC_THREAD_FUNC(sslw_child)
    struct packet_object po;
    int direction, ret_val, data_read;
    struct accepted_entry *ae;
-#if !defined(OS_WINDOWS)
-   struct timespec tm;
-   tm.tv_sec = 0;
-   tm.tv_nsec = 3000*1000;
-#else
-   int timeout = 3000;
-#endif
 
    ae = (struct accepted_entry *)args;
    ec_thread_init();
@@ -1154,7 +1077,7 @@ EC_THREAD_FUNC(sslw_child)
    ae->fd[SSL_SERVER] = -1;
 
    /* Contact the real server */
-   if (sslw_sync_conn(ae) == -EINVALID) {
+   if (sslw_sync_conn(ae) == -E_INVALID) {
       if (ae->fd[SSL_CLIENT] != -1)
          close_socket(ae->fd[SSL_CLIENT]);
       DEBUG_MSG("FAILED TO FIND PEER");
@@ -1163,7 +1086,7 @@ EC_THREAD_FUNC(sslw_child)
    }	    
 	    
    if ((ae->status & SSL_ENABLED) && 
-      sslw_sync_ssl(ae) == -EINVALID) {
+      sslw_sync_ssl(ae) == -E_INVALID) {
       sslw_wipe_connection(ae);
       ec_thread_exit();
    }
@@ -1186,7 +1109,7 @@ EC_THREAD_FUNC(sslw_child)
          BREAK_ON_ERROR(ret_val,ae,po);
 	 
          /* if we have data to read */
-         if (ret_val == ESUCCESS) {
+         if (ret_val == E_SUCCESS) {
             data_read = 1;
 
 
@@ -1211,11 +1134,7 @@ EC_THREAD_FUNC(sslw_child)
       /* XXX - Set a proper sleep time */
       /* Should we poll both fd's instead of guessing and sleeping? */
       if (!data_read)
-#if defined(OS_WINDOWS)
-        usleep(timeout);
-#else
-        nanosleep(&tm, NULL);
-#endif
+         ec_usleep(3000); // 3ms
    }
 
    return NULL;
@@ -1231,7 +1150,7 @@ static int sslw_remove_sts(struct packet_object *po)
 	size_t slen = strlen("\r\nStrict-Transport-Security:");
 
 	if (!memmem(po->DATA.data, po->DATA.len, "\r\nStrict-Transport-Security:", slen)) {
-		return -ENOTFOUND;
+		return -E_NOTFOUND;
 	}
 
 	ptr = po->DATA.data;
@@ -1269,7 +1188,7 @@ static int sslw_remove_sts(struct packet_object *po)
 	po->flags |= PO_MODIFIED;
 
 
-	return ESUCCESS;
+	return E_SUCCESS;
 
 }
 
@@ -1346,7 +1265,6 @@ static void sslw_create_session(struct ec_session **s, struct packet_object *po)
    /* alloc of data elements */
    SAFE_CALLOC((*s)->data, 1, sizeof(struct ip_addr));
 }
-#endif /* HAVE_OPENSSL */
 
 /* EOF */
 
