@@ -61,9 +61,6 @@ static void wdg_dialog_move(struct wdg_object *wo, int key);
 static int wdg_dialog_mouse_move(struct wdg_object *wo, struct wdg_mouse_event *mouse);
 static void wdg_dialog_callback(struct wdg_object *wo);
 
-void wdg_dialog_text(wdg_t *wo, size_t flags, const char *text);
-void wdg_dialog_add_callback(wdg_t *wo, size_t flag, void (*callback)(void));
-
 /*******************************************/
 
 /* 
@@ -121,7 +118,7 @@ static int wdg_dialog_destroy(struct wdg_object *wo)
 
    WDG_SAFE_FREE(wo->extend);
 
-   return WDG_ESUCCESS;
+   return WDG_E_SUCCESS;
 }
 
 /* 
@@ -131,7 +128,7 @@ static int wdg_dialog_resize(struct wdg_object *wo)
 {
    wdg_dialog_redraw(wo);
 
-   return WDG_ESUCCESS;
+   return WDG_E_SUCCESS;
 }
 
 /* 
@@ -193,7 +190,7 @@ static int wdg_dialog_redraw(struct wdg_object *wo)
 
       /* create the outher window */
       if ((ww->win = newwin(l, c, y, x)) == NULL)
-         return -WDG_EFATAL;
+         return -WDG_E_FATAL;
 
       /* draw the borders */
       wdg_dialog_border(wo);
@@ -201,7 +198,7 @@ static int wdg_dialog_redraw(struct wdg_object *wo)
 
       /* create the inner (actual) window */
       if ((ww->sub = newwin(l - 4, c - 4, y + 2, x + 2)) == NULL)
-         return -WDG_EFATAL;
+         return -WDG_E_FATAL;
       
       /* set the window color */
       wbkgdset(ww->sub, COLOR_PAIR(wo->window_color));
@@ -222,7 +219,7 @@ static int wdg_dialog_redraw(struct wdg_object *wo)
    
    wo->flags |= WDG_OBJ_VISIBLE;
 
-   return WDG_ESUCCESS;
+   return WDG_E_SUCCESS;
 }
 
 /* 
@@ -236,7 +233,7 @@ static int wdg_dialog_get_focus(struct wdg_object *wo)
    /* redraw the window */
    wdg_dialog_redraw(wo);
    
-   return WDG_ESUCCESS;
+   return WDG_E_SUCCESS;
 }
 
 /* 
@@ -250,7 +247,7 @@ static int wdg_dialog_lost_focus(struct wdg_object *wo)
    /* redraw the window */
    wdg_dialog_redraw(wo);
    
-   return WDG_ESUCCESS;
+   return WDG_E_SUCCESS;
 }
 
 /* 
@@ -267,10 +264,10 @@ static int wdg_dialog_get_msg(struct wdg_object *wo, int key, struct wdg_mouse_e
          if (wenclose(ww->win, mouse->y, mouse->x)) {
             wdg_set_focus(wo);
             /* if the mouse click was over a button */
-            if (wdg_dialog_mouse_move(wo, mouse) == WDG_ESUCCESS)
+            if (wdg_dialog_mouse_move(wo, mouse) == WDG_E_SUCCESS)
                wdg_dialog_callback(wo);
          } else 
-            return -WDG_ENOTHANDLED;
+            return -WDG_E_NOTHANDLED;
          break;
 
       case KEY_LEFT:
@@ -285,11 +282,11 @@ static int wdg_dialog_get_msg(struct wdg_object *wo, int key, struct wdg_mouse_e
          
       /* message not handled */
       default:
-         return -WDG_ENOTHANDLED;
+         return -WDG_E_NOTHANDLED;
          break;
    }
   
-   return WDG_ESUCCESS;
+   return WDG_E_SUCCESS;
 }
 
 /*
@@ -388,7 +385,7 @@ static void wdg_dialog_get_size(struct wdg_object *wo, size_t *lines, size_t *co
 {
    WDG_WO_EXT(struct wdg_dialog, ww);
    char *p;
-   size_t t = 0;
+   size_t t = 0, wwtextlen;
 
    /* initialize them */
    *lines = 1;
@@ -398,7 +395,8 @@ static void wdg_dialog_get_size(struct wdg_object *wo, size_t *lines, size_t *co
     * parse the text message and find how many '\n' are present.
     * also calculate the longest string between two '\n'
     */
-   for (p = ww->text; p < ww->text + strlen(ww->text); p++) {
+   wwtextlen = strlen(ww->text);
+   for (p = ww->text; p < ww->text + wwtextlen; p++) {
       /* count the chars */
       t++;
       /* at the newline (or end of string) make the calculus */
@@ -500,7 +498,7 @@ static int wdg_dialog_mouse_move(struct wdg_object *wo, struct wdg_mouse_event *
 
    /* not on the button line */
    if (mouse->y != y + 2 + l - 1)
-      return -WDG_ENOTHANDLED;
+      return -WDG_E_NOTHANDLED;
 
    /* calculate the length of the buttons */
    for (i = 0; i < WDG_DIALOG_MAX_BUTTON; i++) 
@@ -514,13 +512,13 @@ static int wdg_dialog_mouse_move(struct wdg_object *wo, struct wdg_mouse_event *
       /* if the mouse is over a title */
       if (mouse->x >= x && mouse->x < x + strlen(ww->buttons[i].label) ) {
          ww->focus_button = i;
-         return WDG_ESUCCESS;
+         return WDG_E_SUCCESS;
       }
       /* move the pointer */   
       x += strlen(ww->buttons[i].label);
    }    
    
-   return -WDG_ENOTHANDLED;
+   return -WDG_E_NOTHANDLED;
 }
 
 /*
