@@ -18,6 +18,7 @@
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
 */
+#include <ec.h>
 
 #include <wdg.h>
 
@@ -46,7 +47,7 @@ struct wdg_file_handle {
    struct dirent **namelist;
    char curpath[PATH_MAX];
    char initpath[PATH_MAX];
-   void (*callback)(char *path, char *file);
+   void (*callback)(const char *path, char *file);
 };
 
 /* PROTOS */
@@ -66,9 +67,7 @@ static void wdg_file_menu_create(struct wdg_object *wo);
 
 static int wdg_file_virtualize(int key);
 static int wdg_file_driver(struct wdg_object *wo, int key, struct wdg_mouse_event *mouse);
-static void wdg_file_callback(struct wdg_object *wo, char *path, char *file);
-
-void wdg_file_set_callback(wdg_t *wo, void (*callback)(char *path, char *file));
+static void wdg_file_callback(struct wdg_object *wo, const char *path, char *file);
 
 /*******************************************/
 
@@ -123,12 +122,12 @@ static int wdg_file_destroy(struct wdg_object *wo)
    /* dealloc the structures */
    delwin(ww->win);
    
-   /* restore the initial workind direcory */
+   /* restore the initial working directory */
    chdir(ww->initpath);
 
    WDG_SAFE_FREE(wo->extend);
 
-   return WDG_ESUCCESS;
+   return WDG_E_SUCCESS;
 }
 
 /* 
@@ -138,7 +137,7 @@ static int wdg_file_resize(struct wdg_object *wo)
 {
    wdg_file_redraw(wo);
 
-   return WDG_ESUCCESS;
+   return WDG_E_SUCCESS;
 }
 
 /* 
@@ -197,7 +196,7 @@ static int wdg_file_redraw(struct wdg_object *wo)
 
       /* create the menu window (fixed dimensions) */
       if ((ww->win = newwin(l, c, y, x)) == NULL)
-         return -WDG_EFATAL;
+         return -WDG_E_FATAL;
 
       /* create the file list */
       wdg_file_menu_create(wo);
@@ -222,7 +221,7 @@ static int wdg_file_redraw(struct wdg_object *wo)
    
    wo->flags |= WDG_OBJ_VISIBLE;
 
-   return WDG_ESUCCESS;
+   return WDG_E_SUCCESS;
 }
 
 /* 
@@ -236,7 +235,7 @@ static int wdg_file_get_focus(struct wdg_object *wo)
    /* redraw the window */
    wdg_file_redraw(wo);
    
-   return WDG_ESUCCESS;
+   return WDG_E_SUCCESS;
 }
 
 /* 
@@ -250,7 +249,7 @@ static int wdg_file_lost_focus(struct wdg_object *wo)
    /* redraw the window */
    wdg_file_redraw(wo);
    
-   return WDG_ESUCCESS;
+   return WDG_E_SUCCESS;
 }
 
 /* 
@@ -268,10 +267,10 @@ static int wdg_file_get_msg(struct wdg_object *wo, int key, struct wdg_mouse_eve
          if (wenclose(ww->win, mouse->y, mouse->x)) {
             wdg_set_focus(wo);
             /* pass it to the menu */
-            if (wdg_file_driver(wo, key, mouse) != WDG_ESUCCESS)
+            if (wdg_file_driver(wo, key, mouse) != WDG_E_SUCCESS)
                wdg_file_redraw(wo);
          } else 
-            return -WDG_ENOTHANDLED;
+            return -WDG_E_NOTHANDLED;
          break;
 
       case KEY_RETURN:
@@ -281,10 +280,10 @@ static int wdg_file_get_msg(struct wdg_object *wo, int key, struct wdg_mouse_eve
       case KEY_NPAGE:
          /* move only if focused */
          if (wo->flags & WDG_OBJ_FOCUSED) {
-            if (wdg_file_driver(wo, key, mouse) != WDG_ESUCCESS)
+            if (wdg_file_driver(wo, key, mouse) != WDG_E_SUCCESS)
                wdg_file_redraw(wo);
          } else
-            return -WDG_ENOTHANDLED;
+            return -WDG_E_NOTHANDLED;
          break;
         
       case KEY_ESC:
@@ -295,11 +294,11 @@ static int wdg_file_get_msg(struct wdg_object *wo, int key, struct wdg_mouse_eve
          
       /* message not handled */
       default:
-         return -WDG_ENOTHANDLED;
+         return -WDG_E_NOTHANDLED;
          break;
    }
   
-   return WDG_ESUCCESS;
+   return WDG_E_SUCCESS;
 }
 
 /*
@@ -376,6 +375,9 @@ static int wdg_file_driver(struct wdg_object *wo, int key, struct wdg_mouse_even
    WDG_WO_EXT(struct wdg_file_handle, ww);
    int c;
    struct stat buf;
+
+   /* variable currently not used */
+   (void) mouse;
    
    c = menu_driver(ww->m, wdg_file_virtualize(key) );
    
@@ -387,24 +389,24 @@ static int wdg_file_driver(struct wdg_object *wo, int key, struct wdg_mouse_even
    if (c == E_UNKNOWN_COMMAND) {
       /* the item is not selectable (probably selected with mouse) */
       if ( !(item_opts(current_item(ww->m)) & O_SELECTABLE) )
-         return WDG_ESUCCESS;
+         return WDG_E_SUCCESS;
          
       stat(item_name(current_item(ww->m)), &buf);
       /* if it is a directory, change to it */
       if (S_ISDIR(buf.st_mode)) {
          chdir(item_name(current_item(ww->m)));
-         return -WDG_ENOTHANDLED;
+         return -WDG_E_NOTHANDLED;
       } else {
          /* invoke the callback and return */
          wdg_file_callback(wo, ww->curpath, (char *)item_name(current_item(ww->m)));
-         return WDG_ESUCCESS;
+         return WDG_E_SUCCESS;
       }
    
    }
 
    wnoutrefresh(ww->mwin);
       
-   return WDG_ESUCCESS;
+   return WDG_E_SUCCESS;
 }
 
 /*
@@ -564,10 +566,10 @@ static void wdg_file_menu_create(struct wdg_object *wo)
  * destroy the dialog and
  * call the function associated to the file open dialog
  */
-static void wdg_file_callback(struct wdg_object *wo, char *path, char *file)
+static void wdg_file_callback(struct wdg_object *wo, const char *path, char *file)
 {
    WDG_WO_EXT(struct wdg_file_handle, ww);
-   void (*callback)(char *, char *);
+   void (*callback)(const char *, char *);
    char *p, *f;
    
    WDG_DEBUG_MSG("wdg_file_callback");
@@ -592,7 +594,7 @@ static void wdg_file_callback(struct wdg_object *wo, char *path, char *file)
 /*
  * the user should use it to associate a callback to the file selection
  */
-void wdg_file_set_callback(wdg_t *wo, void (*callback)(char *path, char *file))
+void wdg_file_set_callback(wdg_t *wo, void (*callback)(const char *path, char *file))
 {
    WDG_WO_EXT(struct wdg_file_handle, ww);
   
