@@ -49,15 +49,14 @@ help_pair help_list[] = {
 };
 
 /* proto */
-void gtkui_help(void);
 void gtkui_help_open(char *file);
 void gtkui_help_selected(GtkTreeSelection *treeselection, gpointer data);
 
-/***#****************************************/
+/********************************************/
 
 void gtkui_help(void)
 {
-   GtkWidget *dialog, *scrolled, *treeview, *hbox, *textview;
+   GtkWidget *dialog, *scrolled, *treeview, *hbox, *textview, *content_area;
    GtkCellRenderer   *renderer;
    GtkTreeViewColumn *column;
    GtkTreeIter iter;
@@ -68,11 +67,18 @@ void gtkui_help(void)
    dialog = gtk_dialog_new_with_buttons(EC_PROGRAM" Help", GTK_WINDOW (window),
                                         GTK_DIALOG_MODAL, GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE, NULL);
    gtk_window_set_default_size(GTK_WINDOW (dialog), 780, 580);
+#if !GTK_CHECK_VERSION(2, 22, 0) // depricated since Gtk 2.22
    gtk_dialog_set_has_separator(GTK_DIALOG (dialog), TRUE);
+#endif
    gtk_container_set_border_width(GTK_CONTAINER (dialog), 5);
 
+#if GTK_CHECK_VERSION(3, 0, 0)
+   hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 6);
+#else
    hbox = gtk_hbox_new (FALSE, 6);
-   gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox), hbox, TRUE, TRUE, 0);
+#endif
+   content_area = gtk_dialog_get_content_area(GTK_DIALOG(dialog));
+   gtk_box_pack_start(GTK_BOX(content_area), hbox, TRUE, TRUE, 0);
 
    scrolled = gtk_scrolled_window_new(NULL, NULL);
    gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW (scrolled), GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC);
@@ -129,27 +135,57 @@ void gtkui_help(void)
 
 void gtkui_help_open(char *file) {
    const char *full = "sh -c \"man %s | col -b\"";
-   char *data = NULL, *errors = NULL, *cmd;
+   char *data = NULL, *unicode = NULL, *errors = NULL, *cmd;
    gboolean ret = FALSE;
    gint len = 0;
 
-   len = strlen(file) + strlen(full);
+   len = strlen(file) + strlen(full) +1;
    cmd = g_malloc(sizeof(char) * len);
    snprintf(cmd, len, full, file);
+   // try to find the system installed man
    ret = g_spawn_command_line_sync(cmd, &data, &errors, NULL, NULL);
    g_free(cmd);
 
-   /* TODO: use local copy of manpages as backup */
    if(ret && errors && strlen(errors) > 0) {
-      ui_error(errors);
       g_free(errors);
+      // system man not found, try non-standard man(8) installation directory
+      full = "sh -c \"man -M " MAN_INSTALLDIR " %s | col -b\"";
+      len = strlen(file) + strlen(full) +1;
+      cmd = g_malloc(sizeof(char) * len);
+      snprintf(cmd, len, full, file);
+      ret = g_spawn_command_line_sync(cmd, &data, &errors, NULL, NULL);
+      g_free(cmd);
+      if(ret && errors && strlen(errors) > 0) {
+         g_free(errors);
+         // man not found in the man installation directory, try build directory
+         full = "sh -c \"man ./man/%s.8 | col -b\"";
+         len = strlen(file) + strlen(full) +1;
+         cmd = g_malloc(sizeof(char) * len);
+         snprintf(cmd, len, full, file);
+         ret = g_spawn_command_line_sync(cmd, &data, &errors, NULL, NULL);
+         g_free(cmd);
+         if(ret && errors && strlen(errors) > 0) {
+           g_free(errors);
+           // man(8) in the build directory not found, but etter.conf is man(5)
+           full = "sh -c \"man ./man/%s.5 | col -b\"";
+           len = strlen(file) + strlen(full) +1;
+           cmd = g_malloc(sizeof(char) * len);
+           snprintf(cmd, len, full, file);
+           ret = g_spawn_command_line_sync(cmd, &data, &errors, NULL, NULL);
+           g_free(cmd);
+           if(ret && errors && strlen(errors) > 0) {
+             ui_error(errors);
+             g_free(errors);
+           }
+         }
+      }
    }
 
    /* print output of command in help window */
    if(data && ret) {
-      gtk_text_buffer_set_text(textbuf, "", -1);
-   
-      gtkui_details_print(textbuf, data);
+      if ((unicode = gtkui_utf8_validate(data)))
+         gtk_text_buffer_set_text(textbuf, unicode, -1);
+
       g_free(data);
    }
 }
@@ -159,6 +195,9 @@ void gtkui_help_selected(GtkTreeSelection *treeselection, gpointer data) {
    GtkTreeModel *model;
    gchar *file;
 
+   /* variable not used */
+   (void) data;
+
    if (gtk_tree_selection_get_selected (GTK_TREE_SELECTION (treeselection), &model, &iter)) {
       gtk_tree_model_get (model, &iter, 1, &file, -1);
       if(!file) return;
