@@ -21,17 +21,11 @@
 
 #include <ec.h>
 #include <ec_gtk.h>
+#include <ec_strings.h>
 
 /* proto */
 
-void toggle_reverse(void);
-void gtkui_select_protocol(void);
-void wipe_targets(void);
-void gtkui_select_targets(void);
-void gtkui_current_targets(void);
-static void set_protocol(void);
 static void set_targets(void);
-void gtkui_create_targets_array(void);
 static void gtkui_add_target1(void *);
 static void gtkui_add_target2(void *);
 static void add_target1(void);
@@ -84,6 +78,11 @@ void wipe_targets(void)
  */
 void gtkui_select_protocol(void)
 {
+   GtkWidget *dialog, *content, *radio, *hbox, *frame;
+   GSList *list = NULL;
+   gint active = 1;
+   enum {proto_udp, proto_tcp, proto_all};
+
    DEBUG_MSG("gtk_select_protocol");
 
    /* this will contain 'all', 'tcp' or 'udp' */
@@ -92,17 +91,65 @@ void gtkui_select_protocol(void)
       strncpy(GBL_OPTIONS->proto, "all", 3);
    }
 
-   gtkui_input("Protocol :", GBL_OPTIONS->proto, 3, set_protocol);
-}
+   /* create dialog for selecting the protocol */
+   dialog = gtk_dialog_new_with_buttons("Set protocol", GTK_WINDOW(window),
+                                        GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
+                                        GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+                                        GTK_STOCK_OK, GTK_RESPONSE_OK,
+                                        NULL);
+   content = gtk_dialog_get_content_area(GTK_DIALOG(dialog));
 
-static void set_protocol(void)
-{
-   if (strcasecmp(GBL_OPTIONS->proto, "all") &&
-       strcasecmp(GBL_OPTIONS->proto, "tcp") &&
-       strcasecmp(GBL_OPTIONS->proto, "udp")) {
-      ui_error("Invalid protocol");
-      SAFE_FREE(GBL_OPTIONS->proto);
+   frame = gtk_frame_new("Select the protocol");
+   gtk_container_add(GTK_CONTAINER(content), frame);
+
+#if GTK_CHECK_VERSION(3, 0, 0)
+   hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 10);
+#else
+   hbox = gtk_hbox_new(FALSE, 10);
+#endif
+   gtk_container_add(GTK_CONTAINER(frame), hbox);
+
+   radio = gtk_radio_button_new_with_mnemonic(NULL, "a_ll");
+   gtk_box_pack_start(GTK_BOX(hbox), radio, TRUE, TRUE, 2);
+   if (!strncasecmp(GBL_OPTIONS->proto, "all", 4))
+      gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(radio), TRUE);
+
+   radio = gtk_radio_button_new_with_mnemonic_from_widget(GTK_RADIO_BUTTON(radio), "_tcp");
+   gtk_box_pack_start(GTK_BOX(hbox), radio, TRUE, TRUE, 2);
+   if (!strncasecmp(GBL_OPTIONS->proto, "tcp", 4))
+      gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(radio), TRUE);
+
+   radio = gtk_radio_button_new_with_mnemonic_from_widget(GTK_RADIO_BUTTON(radio), "_udp");
+   gtk_box_pack_start(GTK_BOX(hbox), radio, TRUE, TRUE, 2);
+   if (!strncasecmp(GBL_OPTIONS->proto, "udp", 4))
+      gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(radio), TRUE);
+
+
+   gtk_widget_grab_focus(gtk_dialog_get_widget_for_response(GTK_DIALOG(dialog), GTK_RESPONSE_OK));
+   gtk_widget_show_all(dialog);
+
+   if (gtk_dialog_run(GTK_DIALOG(dialog)) == GTK_RESPONSE_OK) {
+      list = gtk_radio_button_get_group(GTK_RADIO_BUTTON(radio));
+      for(active = 0; list != NULL; list = list->next) {
+         if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(list->data))) {
+            switch (active) {
+               case proto_all:
+                  strncpy(GBL_OPTIONS->proto, "all", 4);
+                  break;
+               case proto_tcp:
+                  strncpy(GBL_OPTIONS->proto, "tcp", 4);
+                  break;
+               case proto_udp:
+                  strncpy(GBL_OPTIONS->proto, "udp", 4);
+                  break;
+            }
+         }
+         active++;
+      } 
    }
+
+   gtk_widget_destroy(dialog);
+
 }
 
 /*
@@ -110,51 +157,170 @@ static void set_protocol(void)
  */
 void gtkui_select_targets(void)
 {
-   GtkWidget *dialog, *hbox, *label, *entry1, *entry2;  
-   
-#define TARGET_LEN 50
-   
+   GtkWidget *dialog, *label, *table, *content;  
+   GtkWidget *frame1, *frame2;
+   GtkWidget *t1_mac, *t1_ip, *t1_port, *t2_mac, *t2_ip, *t2_port;
+   gint ncols = 2, nrows = 3;
+#ifdef WITH_IPV6
+   GtkWidget *t1_ipv6, *t2_ipv6;
+   nrows = 4;
+#endif
+
+#define TARGET_LEN ETH_ASCII_ADDR_LEN + 1 + \
+                   IP_ASCII_ADDR_LEN + 1 + \
+                   IP6_ASCII_ADDR_LEN + 1 + \
+                   5 + 1
+
    DEBUG_MSG("gtk_select_targets");
 
    dialog = gtk_dialog_new_with_buttons("Enter Targets", GTK_WINDOW(window),
-                                        GTK_DIALOG_MODAL, GTK_STOCK_OK, GTK_RESPONSE_ACCEPT,
-                                        GTK_STOCK_CANCEL, GTK_RESPONSE_REJECT, NULL);
-   gtk_container_set_border_width (GTK_CONTAINER (GTK_DIALOG(dialog)->vbox), 20);
+                                        GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT, 
+                                        GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL, 
+                                        GTK_STOCK_OK, GTK_RESPONSE_OK,
+                                        NULL);
+   content = gtk_dialog_get_content_area(GTK_DIALOG(dialog));
+   gtk_container_set_border_width(GTK_CONTAINER(content), 20);
 
-   hbox = gtk_hbox_new(FALSE, 0);
-   label = gtk_label_new ("Target 1: ");
-   
-   gtk_box_pack_start(GTK_BOX (hbox), label, TRUE, TRUE, 0);
-   gtk_widget_show(label);
+   frame1 = gtk_frame_new("Target 1");
+   gtk_container_add(GTK_CONTAINER(content), frame1);
 
-   entry1 = gtk_entry_new_with_max_length(TARGET_LEN);
-   gtk_entry_set_width_chars (GTK_ENTRY (entry1), TARGET_LEN);
-   
-   if (GBL_OPTIONS->target1)
-      gtk_entry_set_text(GTK_ENTRY (entry1), GBL_OPTIONS->target1); 
-   
-   gtk_box_pack_start(GTK_BOX (hbox), entry1, FALSE, FALSE, 0);
-   gtk_widget_show(entry1);
-   gtk_box_pack_start(GTK_BOX (GTK_DIALOG (dialog)->vbox), hbox, TRUE, TRUE, 5);
-   gtk_widget_show(hbox);
+   frame2 = gtk_frame_new("Target 2");
+   gtk_container_add(GTK_CONTAINER(content), frame2);
 
-   hbox = gtk_hbox_new(FALSE, 0);
-   label = gtk_label_new ("Target 2: ");
-   gtk_box_pack_start(GTK_BOX (hbox), label, TRUE, TRUE, 0);
-   gtk_widget_show(label);
+   table = gtk_table_new(nrows, ncols, FALSE);
+   gtk_table_set_row_spacings(GTK_TABLE (table), 5);
+   gtk_table_set_col_spacings(GTK_TABLE (table), 5);
+   gtk_container_set_border_width(GTK_CONTAINER (table), 8);
+   gtk_container_add(GTK_CONTAINER (frame1), table);
 
-   entry2 = gtk_entry_new_with_max_length(TARGET_LEN);
-   gtk_entry_set_width_chars (GTK_ENTRY (entry2), TARGET_LEN);
-   
-   if (GBL_OPTIONS->target2)
-      gtk_entry_set_text(GTK_ENTRY (entry2), GBL_OPTIONS->target2); 
-   
-   gtk_box_pack_start(GTK_BOX (hbox), entry2, FALSE, FALSE, 0);
-   gtk_widget_show(entry2);
-   gtk_box_pack_start(GTK_BOX (GTK_DIALOG (dialog)->vbox), hbox, TRUE, TRUE, 5);
-   gtk_widget_show(hbox);
+   label = gtk_label_new("MAC:");
+   gtk_misc_set_alignment(GTK_MISC (label), 0, 0.5);
+   gtk_table_attach(GTK_TABLE (table), label, 0, 1, 0, 1, GTK_FILL, GTK_FILL, 0, 0);
 
-   if (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_ACCEPT) {
+   t1_mac = gtk_entry_new();
+   gtk_entry_set_max_length(GTK_ENTRY(t1_mac), MAX_ASCII_ADDR_LEN);
+   gtk_entry_set_width_chars(GTK_ENTRY(t1_mac), MAX_ASCII_ADDR_LEN);
+   gtk_table_attach_defaults(GTK_TABLE(table), t1_mac, 1, 2, 0, 1);
+
+   label = gtk_label_new("IP address:");
+   gtk_misc_set_alignment(GTK_MISC (label), 0, 0.5);
+   gtk_table_attach(GTK_TABLE(table), label, 0, 1, 1, 2, GTK_FILL, GTK_FILL, 0, 0);
+
+   t1_ip = gtk_entry_new();
+   gtk_entry_set_max_length(GTK_ENTRY(t1_ip), MAX_ASCII_ADDR_LEN);
+   gtk_entry_set_width_chars(GTK_ENTRY(t1_ip), MAX_ASCII_ADDR_LEN);
+   gtk_table_attach_defaults(GTK_TABLE(table), t1_ip, 1, 2, 1, 2);
+
+#ifdef WITH_IPV6
+   label = gtk_label_new("IPv6 address:");
+   gtk_misc_set_alignment(GTK_MISC (label), 0, 0.5);
+   gtk_table_attach(GTK_TABLE(table), label, 0, 1, 2, 3, GTK_FILL, GTK_FILL, 0, 0);
+
+   t1_ipv6 = gtk_entry_new();
+   gtk_entry_set_max_length(GTK_ENTRY(t1_ipv6), MAX_ASCII_ADDR_LEN);
+   gtk_entry_set_width_chars(GTK_ENTRY(t1_ipv6), MAX_ASCII_ADDR_LEN);
+   gtk_table_attach_defaults(GTK_TABLE(table), t1_ipv6, 1, 2, 2, 3);
+#endif
+
+   label = gtk_label_new("Port:");
+   gtk_misc_set_alignment(GTK_MISC (label), 0, 0.5);
+   gtk_table_attach(GTK_TABLE(table), label, 0, 1, nrows-1, nrows, GTK_FILL, GTK_FILL, 0, 0);
+
+   t1_port = gtk_entry_new();
+   gtk_entry_set_max_length(GTK_ENTRY(t1_port), MAX_ASCII_ADDR_LEN);
+   gtk_entry_set_width_chars(GTK_ENTRY(t1_port), MAX_ASCII_ADDR_LEN);
+   gtk_table_attach_defaults(GTK_TABLE(table), t1_port, 1, 2, nrows-1, nrows);
+
+   /* Fill previously set values */
+   if (GBL_OPTIONS->target1) {
+      gchar **tokens, **p;
+      tokens = g_strsplit(GBL_OPTIONS->target1, "/", nrows);
+      p = tokens;
+
+      /* MAC */
+      gtk_entry_set_text(GTK_ENTRY(t1_mac), *p++);
+      /* IP address */
+      gtk_entry_set_text(GTK_ENTRY(t1_ip), *p++);
+#ifdef WITH_IPV6
+      /* IPv6 address */
+      gtk_entry_set_text(GTK_ENTRY(t1_ipv6), *p++);
+#endif
+      /* Port */
+      gtk_entry_set_text(GTK_ENTRY(t1_port), *p);
+
+      g_strfreev(tokens);
+   }
+
+
+
+   /* Target 2: */
+   table = gtk_table_new(nrows, ncols, FALSE);
+   gtk_table_set_row_spacings(GTK_TABLE (table), 5);
+   gtk_table_set_col_spacings(GTK_TABLE (table), 5);
+   gtk_container_set_border_width(GTK_CONTAINER (table), 8);
+   gtk_container_add(GTK_CONTAINER (frame2), table);
+
+   label = gtk_label_new("MAC:");
+   gtk_misc_set_alignment(GTK_MISC (label), 0, 0.5);
+   gtk_table_attach(GTK_TABLE (table), label, 0, 1, 0, 1, GTK_FILL, GTK_FILL, 0, 0);
+
+   t2_mac = gtk_entry_new();
+   gtk_entry_set_max_length(GTK_ENTRY(t2_mac), MAX_ASCII_ADDR_LEN);
+   gtk_entry_set_width_chars(GTK_ENTRY(t2_mac), MAX_ASCII_ADDR_LEN);
+   gtk_table_attach_defaults(GTK_TABLE(table), t2_mac, 1, 2, 0, 1);
+
+   label = gtk_label_new("IP address:");
+   gtk_misc_set_alignment(GTK_MISC (label), 0, 0.5);
+   gtk_table_attach(GTK_TABLE(table), label, 0, 1, 1, 2, GTK_FILL, GTK_FILL, 0, 0);
+
+   t2_ip = gtk_entry_new();
+   gtk_entry_set_max_length(GTK_ENTRY(t2_ip), MAX_ASCII_ADDR_LEN);
+   gtk_entry_set_width_chars(GTK_ENTRY(t2_ip), MAX_ASCII_ADDR_LEN);
+   gtk_table_attach_defaults(GTK_TABLE(table), t2_ip, 1, 2, 1, 2);
+
+#ifdef WITH_IPV6
+   label = gtk_label_new("IPv6 address:");
+   gtk_misc_set_alignment(GTK_MISC (label), 0, 0.5);
+   gtk_table_attach(GTK_TABLE(table), label, 0, 1, 2, 3, GTK_FILL, GTK_FILL, 0, 0);
+
+   t2_ipv6 = gtk_entry_new();
+   gtk_entry_set_max_length(GTK_ENTRY(t2_ipv6), MAX_ASCII_ADDR_LEN);
+   gtk_entry_set_width_chars(GTK_ENTRY(t2_ipv6), MAX_ASCII_ADDR_LEN);
+   gtk_table_attach_defaults(GTK_TABLE(table), t2_ipv6, 1, 2, 2, 3);
+#endif
+
+   label = gtk_label_new("Port:");
+   gtk_misc_set_alignment(GTK_MISC (label), 0, 0.5);
+   gtk_table_attach(GTK_TABLE(table), label, 0, 1, nrows-1, nrows, GTK_FILL, GTK_FILL, 0, 0);
+
+   t2_port = gtk_entry_new();
+   gtk_entry_set_max_length(GTK_ENTRY(t2_port), MAX_ASCII_ADDR_LEN);
+   gtk_entry_set_width_chars(GTK_ENTRY(t2_port), MAX_ASCII_ADDR_LEN);
+   gtk_table_attach_defaults(GTK_TABLE(table), t2_port, 1, 2, nrows-1, nrows);
+
+   /* Fill previously set values */
+   if (GBL_OPTIONS->target2) {
+      gchar **tokens, **p;
+      tokens = g_strsplit(GBL_OPTIONS->target2, "/", nrows);
+      p = tokens;
+
+      /* MAC */
+      gtk_entry_set_text(GTK_ENTRY(t2_mac), *p++);
+      /* IP address */
+      gtk_entry_set_text(GTK_ENTRY(t2_ip), *p++);
+#ifdef WITH_IPV6
+      /* IPv6 address */
+      gtk_entry_set_text(GTK_ENTRY(t2_ipv6), *p++);
+#endif
+      /* Port */
+      gtk_entry_set_text(GTK_ENTRY(t2_port), *p);
+
+      g_strfreev(tokens);
+   }
+
+   gtk_widget_show_all(dialog);
+
+   if (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_OK) {
       gtk_widget_hide(dialog);
 
       SAFE_FREE(GBL_OPTIONS->target1);
@@ -163,8 +329,29 @@ void gtkui_select_targets(void)
       SAFE_CALLOC(GBL_OPTIONS->target1, TARGET_LEN, sizeof(char));
       SAFE_CALLOC(GBL_OPTIONS->target2, TARGET_LEN, sizeof(char));
 
-      strncpy(GBL_OPTIONS->target1, gtk_entry_get_text(GTK_ENTRY (entry1)), TARGET_LEN);
-      strncpy(GBL_OPTIONS->target2, gtk_entry_get_text(GTK_ENTRY (entry2)), TARGET_LEN);
+#ifdef WITH_IPV6
+      snprintf(GBL_OPTIONS->target1, TARGET_LEN, "%s/%s/%s/%s",
+            gtk_entry_get_text(GTK_ENTRY(t1_mac)),
+            gtk_entry_get_text(GTK_ENTRY(t1_ip)),
+            gtk_entry_get_text(GTK_ENTRY(t1_ipv6)),
+            gtk_entry_get_text(GTK_ENTRY(t1_port)));
+
+      snprintf(GBL_OPTIONS->target2, TARGET_LEN, "%s/%s/%s/%s",
+            gtk_entry_get_text(GTK_ENTRY(t2_mac)),
+            gtk_entry_get_text(GTK_ENTRY(t2_ip)),
+            gtk_entry_get_text(GTK_ENTRY(t2_ipv6)),
+            gtk_entry_get_text(GTK_ENTRY(t2_port)));
+#else
+      snprintf(GBL_OPTIONS->target1, TARGET_LEN, "%s/%s/%s",
+            gtk_entry_get_text(GTK_ENTRY(t1_mac)),
+            gtk_entry_get_text(GTK_ENTRY(t1_ip)),
+            gtk_entry_get_text(GTK_ENTRY(t1_port)));
+
+      snprintf(GBL_OPTIONS->target2, TARGET_LEN, "%s/%s/%s",
+            gtk_entry_get_text(GTK_ENTRY(t2_mac)),
+            gtk_entry_get_text(GTK_ENTRY(t2_ip)),
+            gtk_entry_get_text(GTK_ENTRY(t2_port)));
+#endif
 
       set_targets();
    }
@@ -204,6 +391,8 @@ void gtkui_current_targets(void)
    GtkWidget *scrolled, *treeview, *vbox, *hbox, *button;
    GtkCellRenderer   *renderer;
    GtkTreeViewColumn *column;
+   static gint delete_targets1 = 1;
+   static gint delete_targets2 = 2;
 
    DEBUG_MSG("gtk_current_targets");
 
@@ -220,11 +409,19 @@ void gtkui_current_targets(void)
 
    targets_window = gtkui_page_new("Targets", &gtkui_targets_destroy, &gtkui_targets_detach);
 
+#if GTK_CHECK_VERSION(3, 0, 0)
+   vbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, 0);
+#else
    vbox = gtk_vbox_new(FALSE, 0);
+#endif
    gtk_container_add(GTK_CONTAINER (targets_window), vbox);
    gtk_widget_show(vbox);
 
+#if GTK_CHECK_VERSION(3, 0, 0)
+   hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 5);
+#else
    hbox = gtk_hbox_new(TRUE, 5);
+#endif
    gtk_box_pack_start(GTK_BOX(vbox), hbox, TRUE, TRUE, 0);
    gtk_widget_show(hbox);
 
@@ -269,17 +466,21 @@ void gtkui_current_targets(void)
    gtk_tree_view_append_column (GTK_TREE_VIEW(treeview), column);
 
    /* buttons */
+#if GTK_CHECK_VERSION(3, 0, 0)
+   hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 5);
+#else
    hbox = gtk_hbox_new(TRUE, 5);
+#endif
    gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, FALSE, 0);
 
    button = gtk_button_new_with_mnemonic("Delete");
-   g_signal_connect(G_OBJECT (button), "clicked", G_CALLBACK (gtkui_delete_targets), (gpointer)1);
+   g_signal_connect(G_OBJECT (button), "clicked", G_CALLBACK (gtkui_delete_targets), &delete_targets1);
    gtk_box_pack_start(GTK_BOX(hbox), button, TRUE, TRUE, 0);
    button = gtk_button_new_with_mnemonic("Add");
    g_signal_connect(G_OBJECT (button), "clicked", G_CALLBACK (gtkui_add_target1), NULL);
    gtk_box_pack_start(GTK_BOX(hbox), button, TRUE, TRUE, 0);
    button = gtk_button_new_with_mnemonic("Delete");
-   g_signal_connect(G_OBJECT (button), "clicked", G_CALLBACK (gtkui_delete_targets), (gpointer)2);
+   g_signal_connect(G_OBJECT (button), "clicked", G_CALLBACK (gtkui_delete_targets), &delete_targets2);
    gtk_box_pack_start(GTK_BOX(hbox), button, TRUE, TRUE, 0);
    button = gtk_button_new_with_mnemonic("Add");
    g_signal_connect(G_OBJECT (button), "clicked", G_CALLBACK (gtkui_add_target2), NULL);
@@ -341,6 +542,16 @@ void gtkui_create_targets_array(void)
       gtk_list_store_set (liststore1, &iter, 0, ip_addr_ntoa(&il->ip, tmp), 1, il, -1);
    }
 
+#ifdef WITH_IPV6
+   /* walk TARGET 1 - IPv6 */
+   LIST_FOREACH(il, &GBL_TARGET1->ip6, next) {
+      /* enlarge the array */
+      gtk_list_store_append (liststore1, &iter);
+      /* fill the element */
+      gtk_list_store_set (liststore1, &iter, 0, ip_addr_ntoa(&il->ip, tmp), 1, il, -1);
+   }
+#endif
+
    if(liststore2)
       gtk_list_store_clear(GTK_LIST_STORE (liststore2));
    else
@@ -353,6 +564,16 @@ void gtkui_create_targets_array(void)
       /* fill the element */
       gtk_list_store_set (liststore2, &iter, 0, ip_addr_ntoa(&il->ip, tmp), 1, il, -1);
    }
+   
+#ifdef WITH_IPV6
+   /* walk TARGET 2 - IPv6 */
+   LIST_FOREACH(il, &GBL_TARGET2->ip6, next) {
+      /* enlarge the array */
+      gtk_list_store_append (liststore2, &iter);
+      /* fill the element */
+      gtk_list_store_set (liststore2, &iter, 0, ip_addr_ntoa(&il->ip, tmp), 1, il, -1);
+   }
+#endif
 }
 
 /*
@@ -360,6 +581,9 @@ void gtkui_create_targets_array(void)
  */
 static void gtkui_add_target1(void *entry)
 {
+   /* variable not used */
+   (void) entry;
+
    DEBUG_MSG("gtk_add_target1");
 
    gtkui_input("IP address :", thost, MAX_ASCII_ADDR_LEN, add_target1);
@@ -367,6 +591,9 @@ static void gtkui_add_target1(void *entry)
 
 static void gtkui_add_target2(void *entry)
 {
+   /* variable not used */
+   (void) entry;
+
    DEBUG_MSG("gtk_add_target2");
 
    gtkui_input("IP address :", thost, MAX_ASCII_ADDR_LEN, add_target2);
@@ -375,15 +602,24 @@ static void gtkui_add_target2(void *entry)
 static void add_target1(void)
 {
    struct in_addr ip;
+#ifdef WITH_IPV6
+   struct in6_addr ip6;
+#endif
    struct ip_addr host;
    
-   if (inet_aton(thost, &ip) == 0) {
+   if (inet_pton(AF_INET, thost, &ip) == 1) { /* is IPv4 */
+      ip_addr_init(&host, AF_INET, (u_char *)&ip);
+   }
+#ifdef WITH_IPV6
+   else if (inet_pton(AF_INET6, thost, &ip6) == 1) { /* is IPv6 */
+      ip_addr_init(&host, AF_INET6, (u_char *)&ip6);
+   }
+#endif
+   else { /* neither IPv4 nor IPv6 - inform user */
       gtkui_message("Invalid ip address");
       return;
    }
    
-   ip_addr_init(&host, AF_INET, (char *)&ip);
-
    add_ip_list(&host, GBL_TARGET1);
    
    /* refresh the list */
@@ -393,15 +629,24 @@ static void add_target1(void)
 static void add_target2(void)
 {
    struct in_addr ip;
+#ifdef WITH_IPV6
+   struct in6_addr ip6;
+#endif
    struct ip_addr host;
    
-   if (inet_aton(thost, &ip) == 0) {
+   if (inet_pton(AF_INET, thost, &ip) == 1) { /* is IPv4 */
+      ip_addr_init(&host, AF_INET, (u_char *)&ip);
+   }
+#ifdef WITH_IPV6
+   else if (inet_pton(AF_INET6, thost, &ip6) == 1) { /* is IPv6 */
+      ip_addr_init(&host, AF_INET6, (u_char *)&ip6);
+   }
+#endif
+   else { /* neither IPv4 nor IPv6 - inform user */
       gtkui_message("Invalid ip address");
       return;
    }
    
-   ip_addr_init(&host, AF_INET, (char *)&ip);
-
    add_ip_list(&host, GBL_TARGET2);
    
    /* refresh the list */
@@ -413,8 +658,15 @@ static void gtkui_delete_targets(GtkWidget *widget, gpointer data) {
    GtkTreeIter iter;
    GtkTreeModel *model;
    struct ip_list *il = NULL;
+   gint *type = data;
 
-   switch((int)data) {
+   /* variable not used */
+   (void) widget;
+
+   if (type == NULL)
+       return;
+
+   switch(*type) {
       case 1:
          DEBUG_MSG("gtkui_delete_target: list 1");
          model = GTK_TREE_MODEL (liststore1);
