@@ -25,19 +25,18 @@
 
 #include <fcntl.h>
 
+#define GBL_FREE(x) do{ if (x != NULL) { free(x); x = NULL; } }while(0)
+
 /* global options */
-struct globals gbls;
-
-void clean_exit(int errcode);
-
+struct globals *gbls;
 
 /*******************************************/
 
 int main(int argc, char *argv[])
 {
    int ret;
-
    /* etterlog copyright */
+   globals_alloc();
    fprintf(stdout, "\n" EC_COLOR_BOLD "%s %s" EC_COLOR_END " copyright %s %s\n\n", 
                       GBL_PROGRAM, EC_VERSION, EC_COPYRIGHT, EC_AUTHORS);
   
@@ -48,53 +47,55 @@ int main(int argc, char *argv[])
    /* initialize to all target */
    GBL_TARGET->all_mac = 1;
    GBL_TARGET->all_ip = 1;
+#ifdef WITH_IPV6
+   GBL_TARGET->all_ip6 = 1;
+#endif
    GBL_TARGET->all_port = 1;
    
    /* getopt related parsing...  */
    parse_options(argc, argv);
 
    /* get the global header */
-   ret = get_header(&GBL.hdr);
-   if (ret == -EINVALID)
+   ret = get_header(&GBL->hdr);
+   if (ret == -E_INVALID)
       FATAL_ERROR("Invalid log file");
    
-   fprintf(stderr, "Log file version    : %s\n", GBL.hdr.version);
-   fprintf(stderr, "Timestamp           : %s", ctime((time_t *)&GBL.hdr.tv.tv_sec));
-   fprintf(stderr, "Type                : %s\n\n", (GBL.hdr.type == LOG_PACKET) ? "LOG_PACKET" : "LOG_INFO" );
+   fprintf(stderr, "Log file version    : %s\n", GBL->hdr.version);
+   /* display the date. ec_ctime() has no newline at end. */
+   fprintf(stderr, "Timestamp           : %s [%lu]\n", ec_ctime(&GBL->hdr.tv), GBL->hdr.tv.tv_usec);
+   fprintf(stderr, "Type                : %s\n\n", (GBL->hdr.type == LOG_PACKET) ? "LOG_PACKET" : "LOG_INFO" );
   
    
    /* analyze the logfile */
-   if (GBL.analyze)
+   if (GBL_OPTIONS->analyze)
       analyze();
 
    /* rewind the log file and skip the global header */
    gzrewind(GBL_LOG_FD);
-   get_header(&GBL.hdr);
+   get_header(&GBL->hdr);
    
    /* create the connection table (respecting the filters) */
-   if (GBL.connections)
+   if (GBL_OPTIONS->connections)
       conn_table_create();
 
    /* display the connection table */
-   if (GBL.connections && !GBL.decode)
+   if (GBL_OPTIONS->connections && !GBL_OPTIONS->decode)
       conn_table_display();
 
    /* extract files from the connections */
-   if (GBL.decode)
+   if (GBL_OPTIONS->decode)
       conn_decode();
    
    /* not interested in the content... only analysis */
-   if (GBL.analyze || GBL.connections)
+   if (GBL_OPTIONS->analyze || GBL_OPTIONS->connections)
       return 0;
    
    /* display the content of the logfile */
    display();
    
-   return 0;
-}
+   globals_free();
 
-void clean_exit(int errcode) {
-	exit(errcode);
+   return 0;
 }
 
 /* ANSI color escapes */
@@ -120,8 +121,31 @@ void reset_color(void)
 #endif
 }
 
+void globals_alloc(void)
+{
 
-/* EOF */
+   SAFE_CALLOC(gbls, 1, sizeof(struct globals));
+   SAFE_CALLOC(gbls->options, 1, sizeof(struct el_options));
+   SAFE_CALLOC(gbls->regex, 1, sizeof(regex_t));
+   SAFE_CALLOC(gbls->t, 1, sizeof(struct target_env));
+
+   return;
+}
+
+void globals_free(void)
+{
+   SAFE_FREE(gbls->user);
+   SAFE_FREE(gbls->logfile);
+   SAFE_FREE(gbls->options);
+   SAFE_FREE(gbls->regex);
+   SAFE_FREE(gbls->t);
+   
+   SAFE_FREE(gbls);
+
+   return;
+
+}
+  
 
 // vim:ts=3:expandtab
 
